CatalogService

Struct CatalogService 

pub struct CatalogService { /* private fields */ }
Implements a client for the Cloud Dataplex API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = CatalogService::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_entry_types()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

The primary resources offered by this service are EntryGroups, EntryTypes, AspectTypes, Entries and EntryLinks. They collectively let data administrators organize, manage, secure, and catalog data located across cloud projects in their organization in a variety of storage systems, including Cloud Storage and BigQuery.

Configuration

To configure CatalogService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://dataplex.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

CatalogService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap CatalogService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl CatalogService

pub fn builder() -> ClientBuilder

Returns a builder for CatalogService.

let client = CatalogService::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: CatalogService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_entry_type(&self) -> CreateEntryType

Creates an EntryType.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::EntryType;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let response = client.create_entry_type()
        .set_parent(parent)
        .set_entry_type(
            EntryType::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_entry_type(&self) -> UpdateEntryType

Updates an EntryType.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::EntryType;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.update_entry_type()
        .set_entry_type(
            EntryType::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_entry_type(&self) -> DeleteEntryType

Deletes an EntryType.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    client.delete_entry_type()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn list_entry_types(&self) -> ListEntryTypes

Lists EntryType resources in a project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let mut list = client.list_entry_types()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_entry_type(&self) -> GetEntryType

Gets an EntryType.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.get_entry_type()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_aspect_type(&self) -> CreateAspectType

Creates an AspectType.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::AspectType;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let response = client.create_aspect_type()
        .set_parent(parent)
        .set_aspect_type(
            AspectType::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_aspect_type(&self) -> UpdateAspectType

Updates an AspectType.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::AspectType;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.update_aspect_type()
        .set_aspect_type(
            AspectType::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_aspect_type(&self) -> DeleteAspectType

Deletes an AspectType.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    client.delete_aspect_type()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn list_aspect_types(&self) -> ListAspectTypes

Lists AspectType resources in a project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let mut list = client.list_aspect_types()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_aspect_type(&self) -> GetAspectType

Gets an AspectType.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.get_aspect_type()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_entry_group(&self) -> CreateEntryGroup

Creates an EntryGroup.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::EntryGroup;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let response = client.create_entry_group()
        .set_parent(parent)
        .set_entry_group(
            EntryGroup::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_entry_group(&self) -> UpdateEntryGroup

Updates an EntryGroup.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::EntryGroup;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.update_entry_group()
        .set_entry_group(
            EntryGroup::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_entry_group(&self) -> DeleteEntryGroup

Deletes an EntryGroup.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    client.delete_entry_group()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn list_entry_groups(&self) -> ListEntryGroups

Lists EntryGroup resources in a project and location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let mut list = client.list_entry_groups()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_entry_group(&self) -> GetEntryGroup

Gets an EntryGroup.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.get_entry_group()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_entry(&self) -> CreateEntry

Creates an Entry.

Example
use google_cloud_dataplex_v1::model::Entry;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let response = client.create_entry()
        .set_parent(parent)
        .set_entry_id("entry_id_value")
        .set_entry(
            Entry::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_entry(&self) -> UpdateEntry

Updates an Entry.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::Entry;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.update_entry()
        .set_entry(
            Entry::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_entry(&self) -> DeleteEntry

Deletes an Entry.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.delete_entry()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_entries(&self) -> ListEntries

Lists Entries within an EntryGroup.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let mut list = client.list_entries()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_entry(&self) -> GetEntry

Gets an Entry.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.get_entry()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn lookup_entry(&self) -> LookupEntry

Looks up an entry by name using the permission on the source system.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let response = client.lookup_entry()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn search_entries(&self) -> SearchEntries

Searches for Entries matching the given query and scope.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let mut list = client.search_entries()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn create_metadata_job(&self) -> CreateMetadataJob

Creates a metadata job. For example, use a metadata job to import metadata from a third-party system into Dataplex Universal Catalog.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::MetadataJob;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let response = client.create_metadata_job()
        .set_parent(parent)
        .set_metadata_job(
            MetadataJob::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_metadata_job(&self) -> GetMetadataJob

Gets a metadata job.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.get_metadata_job()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_metadata_jobs(&self) -> ListMetadataJobs

Lists metadata jobs.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let mut list = client.list_metadata_jobs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn cancel_metadata_job(&self) -> CancelMetadataJob

Cancels a metadata job.

If you cancel a metadata import job that is in progress, the changes in the job might be partially applied. We recommend that you reset the state of the entry groups in your project by running another metadata job that reverts the changes from the canceled job.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    client.cancel_metadata_job()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn create_entry_link(&self) -> CreateEntryLink

Creates an Entry Link.

Example
use google_cloud_dataplex_v1::model::EntryLink;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let response = client.create_entry_link()
        .set_parent(parent)
        .set_entry_link(
            EntryLink::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_entry_link(&self) -> UpdateEntryLink

Updates an Entry Link.

Example
use google_cloud_dataplex_v1::model::EntryLink;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.update_entry_link()
        .set_entry_link(
            EntryLink::new().set_name(name)/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_entry_link(&self) -> DeleteEntryLink

Deletes an Entry Link.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.delete_entry_link()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn lookup_entry_links(&self) -> LookupEntryLinks

Looks up Entry Links referencing the specified Entry.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let mut list = client.lookup_entry_links()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn lookup_context(&self) -> LookupContext

Looks up LLM Context for the specified resources.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let response = client.lookup_context()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_entry_link(&self) -> GetEntryLink

Gets an Entry Link.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.get_entry_link()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_metadata_feed(&self) -> CreateMetadataFeed

Creates a MetadataFeed.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::MetadataFeed;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let response = client.create_metadata_feed()
        .set_parent(parent)
        .set_metadata_feed(
            MetadataFeed::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_metadata_feed(&self) -> GetMetadataFeed

Gets a MetadataFeed.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.get_metadata_feed()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_metadata_feeds(&self) -> ListMetadataFeeds

Retrieve a list of MetadataFeeds.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, parent: &str
) -> Result<()> {
    let mut list = client.list_metadata_feeds()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn delete_metadata_feed(&self) -> DeleteMetadataFeed

Deletes a MetadataFeed.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    client.delete_metadata_feed()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn update_metadata_feed(&self) -> UpdateMetadataFeed

Updates a MetadataFeed.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::MetadataFeed;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService, name: &str
) -> Result<()> {
    let response = client.update_metadata_feed()
        .set_metadata_feed(
            MetadataFeed::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service. This method can be called in two ways:

  • List all public locations: Use the path GET /v1/locations.
  • List project-visible locations: Use the path GET /v1/projects/{project_id}/locations. This may include public locations as well as private or other locations specifically visible to the project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &CatalogService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}