DataProductService

Struct DataProductService 

pub struct DataProductService { /* private fields */ }
Implements a client for the Cloud Dataplex API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = DataProductService::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_data_products()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

DataProductService provides APIs for managing data products and the underlying data assets.

Configuration

To configure DataProductService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://dataplex.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

DataProductService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap DataProductService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl DataProductService

pub fn builder() -> ClientBuilder

Returns a builder for DataProductService.

let client = DataProductService::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: DataProductService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_data_product(&self) -> CreateDataProduct

Creates a data product.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::DataProduct;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, parent: &str
) -> Result<()> {
    let response = client.create_data_product()
        .set_parent(parent)
        .set_data_product(
            DataProduct::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_data_product(&self) -> DeleteDataProduct

Deletes a data product. The deletion will fail if the data product is not empty (i.e. contains at least one data asset).

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, name: &str
) -> Result<()> {
    client.delete_data_product()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn get_data_product(&self) -> GetDataProduct

Gets a data product.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, name: &str
) -> Result<()> {
    let response = client.get_data_product()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_data_products(&self) -> ListDataProducts

Lists data products for a given project.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, parent: &str
) -> Result<()> {
    let mut list = client.list_data_products()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn update_data_product(&self) -> UpdateDataProduct

Updates a data product.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::DataProduct;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, name: &str
) -> Result<()> {
    let response = client.update_data_product()
        .set_data_product(
            DataProduct::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_data_asset(&self) -> CreateDataAsset

Creates a data asset.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::DataAsset;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, parent: &str
) -> Result<()> {
    let response = client.create_data_asset()
        .set_parent(parent)
        .set_data_asset(
            DataAsset::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_data_asset(&self) -> UpdateDataAsset

Updates a data asset.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::DataAsset;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, name: &str
) -> Result<()> {
    let response = client.update_data_asset()
        .set_data_asset(
            DataAsset::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_data_asset(&self) -> DeleteDataAsset

Deletes a data asset.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, name: &str
) -> Result<()> {
    client.delete_data_asset()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn get_data_asset(&self) -> GetDataAsset

Gets a data asset.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, name: &str
) -> Result<()> {
    let response = client.get_data_asset()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_data_assets(&self) -> ListDataAssets

Lists data assets for a given data product.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService, parent: &str
) -> Result<()> {
    let mut list = client.list_data_assets()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service. This method can be called in two ways:

  • List all public locations: Use the path GET /v1/locations.
  • List project-visible locations: Use the path GET /v1/projects/{project_id}/locations. This may include public locations as well as private or other locations specifically visible to the project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataProductService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}