DataScanService

Struct DataScanService 

pub struct DataScanService { /* private fields */ }
Implements a client for the Cloud Dataplex API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = DataScanService::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_data_scans()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

DataScanService manages DataScan resources which can be configured to run various types of data scanning workload and generate enriched metadata (e.g. Data Profile, Data Quality) for the data source.

Configuration

To configure DataScanService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://dataplex.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

DataScanService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap DataScanService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl DataScanService

pub fn builder() -> ClientBuilder

Returns a builder for DataScanService.

let client = DataScanService::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: DataScanService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_data_scan(&self) -> CreateDataScan

Creates a DataScan resource.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::DataScan;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService, parent: &str
) -> Result<()> {
    let response = client.create_data_scan()
        .set_parent(parent)
        .set_data_scan(
            DataScan::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_data_scan(&self) -> UpdateDataScan

Updates a DataScan resource.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::DataScan;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService, name: &str
) -> Result<()> {
    let response = client.update_data_scan()
        .set_data_scan(
            DataScan::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_data_scan(&self) -> DeleteDataScan

Deletes a DataScan resource.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService, name: &str
) -> Result<()> {
    client.delete_data_scan()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn get_data_scan(&self) -> GetDataScan

Gets a DataScan resource.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService, name: &str
) -> Result<()> {
    let response = client.get_data_scan()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_data_scans(&self) -> ListDataScans

Lists DataScans.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService, parent: &str
) -> Result<()> {
    let mut list = client.list_data_scans()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn run_data_scan(&self) -> RunDataScan

Runs an on-demand execution of a DataScan

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let response = client.run_data_scan()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_data_scan_job(&self) -> GetDataScanJob

Gets a DataScanJob resource.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService, name: &str
) -> Result<()> {
    let response = client.get_data_scan_job()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_data_scan_jobs(&self) -> ListDataScanJobs

Lists DataScanJobs under the given DataScan.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService, parent: &str
) -> Result<()> {
    let mut list = client.list_data_scan_jobs()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn generate_data_quality_rules(&self) -> GenerateDataQualityRules

Generates recommended data quality rules based on the results of a data profiling scan.

Use the recommendations to build rules for a data quality scan.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let response = client.generate_data_quality_rules()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service. This method can be called in two ways:

  • List all public locations: Use the path GET /v1/locations.
  • List project-visible locations: Use the path GET /v1/projects/{project_id}/locations. This may include public locations as well as private or other locations specifically visible to the project.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn set_iam_policy(&self) -> SetIamPolicy

Sets the access control policy on the specified resource. Replaces any existing policy.

Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let response = client.set_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_iam_policy(&self) -> GetIamPolicy

Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let response = client.get_iam_policy()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn test_iam_permissions(&self) -> TestIamPermissions

Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.

Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let response = client.test_iam_permissions()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_dataplex_v1::Result;
async fn sample(
   client: &DataScanService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}