pub struct DataTaxonomyService { /* private fields */ }Expand description
Implements a client for the Cloud Dataplex API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = DataTaxonomyService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_data_taxonomies()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
DataTaxonomyService enables attribute-based governance. The resources currently offered include DataTaxonomy and DataAttribute.
Configuration
To configure DataTaxonomyService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://dataplex.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
DataTaxonomyService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap DataTaxonomyService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl DataTaxonomyService
impl DataTaxonomyService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for DataTaxonomyService.
let client = DataTaxonomyService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: DataTaxonomyService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: DataTaxonomyService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the clientโs behavior.
Sourcepub fn create_data_taxonomy(&self) -> CreateDataTaxonomy
๐Deprecated
pub fn create_data_taxonomy(&self) -> CreateDataTaxonomy
Create a DataTaxonomy resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::DataTaxonomy;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, parent: &str
) -> Result<()> {
let response = client.create_data_taxonomy()
.set_parent(parent)
.set_data_taxonomy(
DataTaxonomy::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_data_taxonomy(&self) -> UpdateDataTaxonomy
๐Deprecated
pub fn update_data_taxonomy(&self) -> UpdateDataTaxonomy
Updates a DataTaxonomy resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::DataTaxonomy;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
let response = client.update_data_taxonomy()
.set_data_taxonomy(
DataTaxonomy::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_data_taxonomy(&self) -> DeleteDataTaxonomy
๐Deprecated
pub fn delete_data_taxonomy(&self) -> DeleteDataTaxonomy
Deletes a DataTaxonomy resource. All attributes within the DataTaxonomy must be deleted before the DataTaxonomy can be deleted.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
client.delete_data_taxonomy()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_data_taxonomies(&self) -> ListDataTaxonomies
๐Deprecated
pub fn list_data_taxonomies(&self) -> ListDataTaxonomies
Lists DataTaxonomy resources in a project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, parent: &str
) -> Result<()> {
let mut list = client.list_data_taxonomies()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_data_taxonomy(&self) -> GetDataTaxonomy
๐Deprecated
pub fn get_data_taxonomy(&self) -> GetDataTaxonomy
Retrieves a DataTaxonomy resource.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
let response = client.get_data_taxonomy()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_data_attribute_binding(&self) -> CreateDataAttributeBinding
๐Deprecated
pub fn create_data_attribute_binding(&self) -> CreateDataAttributeBinding
Create a DataAttributeBinding resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::DataAttributeBinding;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, parent: &str
) -> Result<()> {
let response = client.create_data_attribute_binding()
.set_parent(parent)
.set_data_attribute_binding(
DataAttributeBinding::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_data_attribute_binding(&self) -> UpdateDataAttributeBinding
๐Deprecated
pub fn update_data_attribute_binding(&self) -> UpdateDataAttributeBinding
Updates a DataAttributeBinding resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::DataAttributeBinding;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
let response = client.update_data_attribute_binding()
.set_data_attribute_binding(
DataAttributeBinding::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_data_attribute_binding(&self) -> DeleteDataAttributeBinding
๐Deprecated
pub fn delete_data_attribute_binding(&self) -> DeleteDataAttributeBinding
Deletes a DataAttributeBinding resource. All attributes within the DataAttributeBinding must be deleted before the DataAttributeBinding can be deleted.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
client.delete_data_attribute_binding()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_data_attribute_bindings(&self) -> ListDataAttributeBindings
๐Deprecated
pub fn list_data_attribute_bindings(&self) -> ListDataAttributeBindings
Lists DataAttributeBinding resources in a project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, parent: &str
) -> Result<()> {
let mut list = client.list_data_attribute_bindings()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_data_attribute_binding(&self) -> GetDataAttributeBinding
๐Deprecated
pub fn get_data_attribute_binding(&self) -> GetDataAttributeBinding
Retrieves a DataAttributeBinding resource.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
let response = client.get_data_attribute_binding()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_data_attribute(&self) -> CreateDataAttribute
๐Deprecated
pub fn create_data_attribute(&self) -> CreateDataAttribute
Create a DataAttribute resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::model::DataAttribute;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, parent: &str
) -> Result<()> {
let response = client.create_data_attribute()
.set_parent(parent)
.set_data_attribute(
DataAttribute::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_data_attribute(&self) -> UpdateDataAttribute
๐Deprecated
pub fn update_data_attribute(&self) -> UpdateDataAttribute
Updates a DataAttribute resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_dataplex_v1::model::DataAttribute;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
let response = client.update_data_attribute()
.set_data_attribute(
DataAttribute::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_data_attribute(&self) -> DeleteDataAttribute
๐Deprecated
pub fn delete_data_attribute(&self) -> DeleteDataAttribute
Deletes a Data Attribute resource.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
client.delete_data_attribute()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_data_attributes(&self) -> ListDataAttributes
๐Deprecated
pub fn list_data_attributes(&self) -> ListDataAttributes
Lists Data Attribute resources in a DataTaxonomy.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, parent: &str
) -> Result<()> {
let mut list = client.list_data_attributes()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_data_attribute(&self) -> GetDataAttribute
๐Deprecated
pub fn get_data_attribute(&self) -> GetDataAttribute
Retrieves a Data Attribute resource.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService, name: &str
) -> Result<()> {
let response = client.get_data_attribute()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on the specified resource. Replaces any existing policy.
Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED
errors.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of
permissions, not a NOT_FOUND error.
Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may โfail openโ without warning.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_dataplex_v1::Result;
async fn sample(
client: &DataTaxonomyService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for DataTaxonomyService
impl Clone for DataTaxonomyService
Sourcefn clone(&self) -> DataTaxonomyService
fn clone(&self) -> DataTaxonomyService
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more