#[non_exhaustive]pub struct AccessGroupConfig {
pub iam_roles: Vec<String>,
/* private fields */
}Expand description
Configuration for access group inherited from the parent data product.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.iam_roles: Vec<String>Optional. IAM roles granted on the resource to this access group. Role name follows https://cloud.google.com/iam/docs/reference/rest/v1/roles.
Example: [ "roles/bigquery.dataViewer" ]
Implementations
Sourceimpl AccessGroupConfig
impl AccessGroupConfig
pub fn new() -> Self
Sourcepub fn set_iam_roles<T, V>(self, v: T) -> Self
pub fn set_iam_roles<T, V>(self, v: T) -> Self