#[non_exhaustive]pub struct BigQueryPublishingConfig {
pub table_type: TableType,
pub connection: String,
pub location: String,
pub project: String,
/* private fields */
}Expand description
Describes BigQuery publishing configurations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.table_type: TableTypeOptional. Determines whether to publish discovered tables as BigLake external tables or non-BigLake external tables.
connection: StringOptional. The BigQuery connection used to create BigLake tables.
Must be in the form
projects/{project_id}/locations/{location_id}/connections/{connection_id}
location: StringOptional. The location of the BigQuery dataset to publish BigLake external or non-BigLake external tables to.
- If the Cloud Storage bucket is located in a multi-region bucket, then BigQuery dataset can be in the same multi-region bucket or any single region that is included in the same multi-region bucket. The datascan can be created in any single region that is included in the same multi-region bucket
- If the Cloud Storage bucket is located in a dual-region bucket, then BigQuery dataset can be located in regions that are included in the dual-region bucket, or in a multi-region that includes the dual-region. The datascan can be created in any single region that is included in the same dual-region bucket.
- If the Cloud Storage bucket is located in a single region, then BigQuery dataset can be in the same single region or any multi-region bucket that includes the same single region. The datascan will be created in the same single region as the bucket.
- If the BigQuery dataset is in single region, it must be in the same single region as the datascan.
For supported values, refer to https://cloud.google.com/bigquery/docs/locations#supported_locations.
project: StringOptional. The project of the BigQuery dataset to publish BigLake external or non-BigLake external tables to. If not specified, the project of the Cloud Storage bucket will be used. The format is “projects/{project_id_or_number}”.
Implementations
Sourceimpl BigQueryPublishingConfig
impl BigQueryPublishingConfig
Sourcepub fn set_table_type<T: Into<TableType>>(self, v: T) -> Self
pub fn set_table_type<T: Into<TableType>>(self, v: T) -> Self
Sets the value of table_type.
Example
use google_cloud_dataplex_v1::model::data_discovery_spec::big_query_publishing_config::TableType;
let x0 = BigQueryPublishingConfig::new().set_table_type(TableType::External);
let x1 = BigQueryPublishingConfig::new().set_table_type(TableType::Biglake);Sourcepub fn set_connection<T: Into<String>>(self, v: T) -> Self
pub fn set_connection<T: Into<String>>(self, v: T) -> Self
Sets the value of connection.
Example
let x = BigQueryPublishingConfig::new().set_connection("example");Sourcepub fn set_location<T: Into<String>>(self, v: T) -> Self
pub fn set_location<T: Into<String>>(self, v: T) -> Self