#[non_exhaustive]pub enum GenerationScope {
Unspecified,
All,
TableAndColumnDescriptions,
SqlQueries,
UnknownValue(UnknownValue),
}Expand description
The data documentation generation scope. This field contains the possible components of a data documentation scan which can be selectively generated.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified generation scope. If no generation scope is specified, all available documentation components will be generated.
All
All the possible results will be generated.
TableAndColumnDescriptions
Table and column descriptions will be generated.
SqlQueries
SQL queries will be generated.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using GenerationScope::value or GenerationScope::name.
Implementations