RulePathElement

Struct RulePathElement 

#[non_exhaustive]
pub struct RulePathElement { pub source_type: Option<SourceType>, /* private fields */ }
Path Element represents the direct relationship between the rule origin (aspects) to the BigQuery Entry. Ordering of the rule relationship will be maintained such that the first entry in the list is the closest ancestor (BigQuery table itself). A blank source denotes that the rule is derived directly from the DataScan itself.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
source_type: Option<SourceType>

The source type of the rule.

Implementations

Source

impl RulePathElement

pub fn new() -> Self

Creates a new default instance.

pub fn set_source_type<T: Into<Option<SourceType>>>(self, v: T) -> Self

Sets the value of source_type.

Note that all the setters affecting source_type are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::data_quality_rule::rule_source::rule_path_element::EntrySource;
let x = RulePathElement::new().set_source_type(Some(
    google_cloud_dataplex_v1::model::data_quality_rule::rule_source::rule_path_element::SourceType::EntrySource(EntrySource::default().into())));
pub fn entry_source(&self) -> Option<&Box<EntrySource>>

The value of source_type if it holds a EntrySource, None if the field is not set or holds a different branch.

pub fn set_entry_source<T: Into<Box<EntrySource>>>(self, v: T) -> Self

Sets the value of source_type to hold a EntrySource.

Note that all the setters affecting source_type are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::data_quality_rule::rule_source::rule_path_element::EntrySource;
let x = RulePathElement::new().set_entry_source(EntrySource::default()/* use setters */);
assert!(x.entry_source().is_some());
assert!(x.entry_link_source().is_none());

The value of source_type if it holds a EntryLinkSource, None if the field is not set or holds a different branch.

pub fn set_entry_link_source<T: Into<Box<EntryLinkSource>>>(self, v: T) -> Self

Sets the value of source_type to hold a EntryLinkSource.

Note that all the setters affecting source_type are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::data_quality_rule::rule_source::rule_path_element::EntryLinkSource;
let x = RulePathElement::new().set_entry_link_source(EntryLinkSource::default()/* use setters */);
assert!(x.entry_link_source().is_some());
assert!(x.entry_source().is_none());