DebugQuery

Struct DebugQuery 

#[non_exhaustive]
pub struct DebugQuery { pub description: String, pub sql_statement: String, /* private fields */ }
Specifies a SQL statement that is evaluated to return up to 10 scalar values that are used to debug rules. If the rule fails, the values can help diagnose the cause of the failure.

The SQL statement must use GoogleSQL syntax, and must not contain any semicolons.

You can use the data reference parameter ${data()} to reference the source table with all of its precondition filters applied. Examples of precondition filters include row filters, incremental data filters, and sampling. For more information, see Data reference parameter.

You can also name results with an explicit alias using [AS] alias. For more information, see BigQuery explicit aliases.

Example: SELECT MIN(col1) AS min_col1, MAX(col1) AS max_col1 FROM ${data()}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
description: String

Optional. Specifies the description of the debug query.

  • The maximum length is 1,024 characters.
sql_statement: String

Required. Specifies the SQL statement to be executed.

Implementations

Source

impl DebugQuery

pub fn new() -> Self

pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = DebugQuery::new().set_description("example");
pub fn set_sql_statement<T: Into<String>>(self, v: T) -> Self

Sets the value of sql_statement.

Example
let x = DebugQuery::new().set_sql_statement("example");