#[non_exhaustive]pub enum Incremental {
Field(String),
}Expand description
Spec related to incremental scan of the data
When an option is selected for incremental scan, it cannot be unset or changed. If not specified, a data scan will run for all data in the table.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Field(String)
Immutable. The unnested field (of type Date or Timestamp) that contains values which monotonically increase over time.
If not specified, a data scan will run for all data in the table.