#[non_exhaustive]pub struct ExecutionSpec {
pub trigger: Option<Trigger>,
pub incremental: Option<Incremental>,
/* private fields */
}Expand description
DataScan execution settings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trigger: Option<Trigger>Optional. Spec related to how often and when a scan should be triggered.
If not specified, the default is OnDemand, which means the scan will
not run until the user calls RunDataScan API.
incremental: Option<Incremental>Spec related to incremental scan of the data
When an option is selected for incremental scan, it cannot be unset or changed. If not specified, a data scan will run for all data in the table.
Implementations
Sourceimpl ExecutionSpec
impl ExecutionSpec
pub fn new() -> Self
Sourcepub fn set_trigger<T>(self, v: T) -> Self
pub fn set_trigger<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_trigger<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_trigger<T>(self, v: Option<T>) -> Self
Sourcepub fn set_incremental<T: Into<Option<Incremental>>>(self, v: T) -> Self
pub fn set_incremental<T: Into<Option<Incremental>>>(self, v: T) -> Self
Sets the value of incremental.
Note that all the setters affecting incremental are mutually
exclusive.
Example
ⓘ
use google_cloud_dataplex_v1::model::data_scan::execution_spec::Incremental;
let x = ExecutionSpec::new().set_incremental(Some(Incremental::Field("example".to_string())));Sourcepub fn field(&self) -> Option<&String>
pub fn field(&self) -> Option<&String>
The value of incremental
if it holds a Field, None if the field is not set or
holds a different branch.