#[non_exhaustive]pub enum Source {
Entity(String),
Resource(String),
}Expand description
The source is required and immutable. Once it is set, it cannot be change to others.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Entity(String)
Immutable. The Dataplex Universal Catalog entity that represents the data
source (e.g. BigQuery table) for DataScan, of the form:
projects/{project_number}/locations/{location_id}/lakes/{lake_id}/zones/{zone_id}/entities/{entity_id}.
Resource(String)
Immutable. The service-qualified full resource name of the cloud resource for a DataScan job to scan against. The field could either be: Cloud Storage bucket for DataDiscoveryScan Format: //storage.googleapis.com/projects/PROJECT_ID/buckets/BUCKET_ID or BigQuery table of type “TABLE” for DataProfileScan/DataQualityScan/DataDocumentationScan Format: //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID or BigQuery dataset for DataDocumentationScan only Format: //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID