#[non_exhaustive]pub struct EntryReference {
pub name: String,
pub path: String,
pub type: Type,
/* private fields */
}Expand description
Reference to the Entry that is linked through the Entry Link.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Immutable. The relative resource name of the referenced Entry,
of the form:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}
path: StringImmutable. The path in the Entry that is referenced in the Entry Link. Empty path denotes that the Entry itself is referenced in the Entry Link.
type: TypeRequired. Immutable. The reference type of the Entry.
Implementations