#[non_exhaustive]pub enum TransferStatus {
Unspecified,
Migrated,
Transferred,
UnknownValue(UnknownValue),
}Expand description
Denotes the transfer status of a resource. It is unspecified for resources created from Dataplex API.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default value. It is set for resources that were not subject for migration from Data Catalog service.
Migrated
Indicates that a resource was migrated from Data Catalog service but it hasn’t been transferred yet. In particular the resource cannot be updated from Dataplex API.
Transferred
Indicates that a resource was transferred from Data Catalog service. The resource can only be updated from Dataplex API.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using TransferStatus::value or TransferStatus::name.
Implementations