#[non_exhaustive]pub struct Scope {
pub organization_level: bool,
pub projects: Vec<String>,
pub entry_groups: Vec<String>,
/* private fields */
}Expand description
Scope defines the scope of the metadata feed. Scopes are exclusive. Only one of the scopes can be specified.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.organization_level: boolOptional. Whether the metadata feed is at the organization-level.
- If
true, all changes happened to the entries in the same organization as the feed are published. - If
false, you must specify a list of projects or a list of entry groups whose entries you want to listen to.
The default is false.
projects: Vec<String>Optional. The projects whose entries you want to listen to.
Must be in the same organization as the feed.
Must be in the format: projects/{project_id_or_number}.
entry_groups: Vec<String>Optional. The entry groups whose entries you want to listen to.
Must be in the format:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}.
Implementations
Sourceimpl Scope
impl Scope
pub fn new() -> Self
Sourcepub fn set_organization_level<T: Into<bool>>(self, v: T) -> Self
pub fn set_organization_level<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_projects<T, V>(self, v: T) -> Self
pub fn set_projects<T, V>(self, v: T) -> Self
Sourcepub fn set_entry_groups<T, V>(self, v: T) -> Self
pub fn set_entry_groups<T, V>(self, v: T) -> Self