#[non_exhaustive]pub struct Aspect {
pub aspect_type: String,
pub path: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub data: Option<Struct>,
pub aspect_source: Option<AspectSource>,
/* private fields */
}Expand description
An aspect is a single piece of metadata describing an entry.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.aspect_type: StringOutput only. The resource name of the type used to create this Aspect.
path: StringOutput only. The path in the entry under which the aspect is attached.
create_time: Option<Timestamp>Output only. The time when the Aspect was created.
update_time: Option<Timestamp>Output only. The time when the Aspect was last updated.
data: Option<Struct>Required. The content of the aspect, according to its aspect type schema. The maximum size of the field is 120KB (encoded as UTF-8).
aspect_source: Option<AspectSource>Optional. Information related to the source system of the aspect.
Implementations
Sourceimpl Aspect
impl Aspect
pub fn new() -> Self
Sourcepub fn set_aspect_type<T: Into<String>>(self, v: T) -> Self
pub fn set_aspect_type<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = Aspect::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = Aspect::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Aspect::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = Aspect::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = Aspect::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Aspect::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_or_clear_data<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_data<T>(self, v: Option<T>) -> Self
Sourcepub fn set_aspect_source<T>(self, v: T) -> Selfwhere
T: Into<AspectSource>,
pub fn set_aspect_source<T>(self, v: T) -> Selfwhere
T: Into<AspectSource>,
Sets the value of aspect_source.
Example
ⓘ
use google_cloud_dataplex_v1::model::AspectSource;
let x = Aspect::new().set_aspect_source(AspectSource::default()/* use setters */);Sourcepub fn set_or_clear_aspect_source<T>(self, v: Option<T>) -> Selfwhere
T: Into<AspectSource>,
pub fn set_or_clear_aspect_source<T>(self, v: Option<T>) -> Selfwhere
T: Into<AspectSource>,
Sets or clears the value of aspect_source.
Example
ⓘ
use google_cloud_dataplex_v1::model::AspectSource;
let x = Aspect::new().set_or_clear_aspect_source(Some(AspectSource::default()/* use setters */));
let x = Aspect::new().set_or_clear_aspect_source(None::<AspectSource>);Trait Implementations
impl StructuralPartialEq for Aspect