#[non_exhaustive]pub struct AspectType {
pub name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub display_name: String,
pub labels: HashMap<String, String>,
pub etag: String,
pub data_classification: DataClassification,
pub authorization: Option<Authorization>,
pub metadata_template: Option<MetadataTemplate>,
pub transfer_status: TransferStatus,
/* private fields */
}Expand description
AspectType is a template for creating Aspects, and represents the JSON-schema for a given Entry, for example, BigQuery Table Schema.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The relative resource name of the AspectType, of the form: projects/{project_number}/locations/{location_id}/aspectTypes/{aspect_type_id}.
uid: StringOutput only. System generated globally unique ID for the AspectType. If you delete and recreate the AspectType with the same name, then this ID will be different.
create_time: Option<Timestamp>Output only. The time when the AspectType was created.
update_time: Option<Timestamp>Output only. The time when the AspectType was last updated.
description: StringOptional. Description of the AspectType.
display_name: StringOptional. User friendly display name.
labels: HashMap<String, String>Optional. User-defined labels for the AspectType.
etag: StringThe service computes this checksum. The client may send it on update and delete requests to ensure it has an up-to-date value before proceeding.
data_classification: DataClassificationOptional. Immutable. Stores data classification of the aspect.
Immutable. Defines the Authorization for this type.
metadata_template: Option<MetadataTemplate>Required. MetadataTemplate of the aspect.
transfer_status: TransferStatusOutput only. Denotes the transfer status of the Aspect Type. It is unspecified for Aspect Types created from Dataplex API.
Implementations
Sourceimpl AspectType
impl AspectType
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = AspectType::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = AspectType::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = AspectType::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = AspectType::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = AspectType::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = AspectType::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_data_classification<T: Into<DataClassification>>(self, v: T) -> Self
pub fn set_data_classification<T: Into<DataClassification>>(self, v: T) -> Self
Sets the value of data_classification.
Example
use google_cloud_dataplex_v1::model::aspect_type::DataClassification;
let x0 = AspectType::new().set_data_classification(DataClassification::MetadataAndData);Sets the value of authorization.
Example
use google_cloud_dataplex_v1::model::aspect_type::Authorization;
let x = AspectType::new().set_authorization(Authorization::default()/* use setters */);Sets or clears the value of authorization.
Example
use google_cloud_dataplex_v1::model::aspect_type::Authorization;
let x = AspectType::new().set_or_clear_authorization(Some(Authorization::default()/* use setters */));
let x = AspectType::new().set_or_clear_authorization(None::<Authorization>);Sourcepub fn set_metadata_template<T>(self, v: T) -> Selfwhere
T: Into<MetadataTemplate>,
pub fn set_metadata_template<T>(self, v: T) -> Selfwhere
T: Into<MetadataTemplate>,
Sets the value of metadata_template.
Example
use google_cloud_dataplex_v1::model::aspect_type::MetadataTemplate;
let x = AspectType::new().set_metadata_template(MetadataTemplate::default()/* use setters */);Sourcepub fn set_or_clear_metadata_template<T>(self, v: Option<T>) -> Selfwhere
T: Into<MetadataTemplate>,
pub fn set_or_clear_metadata_template<T>(self, v: Option<T>) -> Selfwhere
T: Into<MetadataTemplate>,
Sets or clears the value of metadata_template.
Example
use google_cloud_dataplex_v1::model::aspect_type::MetadataTemplate;
let x = AspectType::new().set_or_clear_metadata_template(Some(MetadataTemplate::default()/* use setters */));
let x = AspectType::new().set_or_clear_metadata_template(None::<MetadataTemplate>);Sourcepub fn set_transfer_status<T: Into<TransferStatus>>(self, v: T) -> Self
pub fn set_transfer_status<T: Into<TransferStatus>>(self, v: T) -> Self
Sets the value of transfer_status.
Example
use google_cloud_dataplex_v1::model::TransferStatus;
let x0 = AspectType::new().set_transfer_status(TransferStatus::Migrated);
let x1 = AspectType::new().set_transfer_status(TransferStatus::Transferred);Trait Implementations
Sourceimpl Clone for AspectType
impl Clone for AspectType
Sourcefn clone(&self) -> AspectType
fn clone(&self) -> AspectType
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more