#[non_exhaustive]pub struct AssetStatus {
pub update_time: Option<Timestamp>,
pub active_assets: i32,
pub security_policy_applying_assets: i32,
/* private fields */
}Expand description
Aggregated status of the underlying assets of a lake or zone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_time: Option<Timestamp>Last update time of the status.
active_assets: i32Number of active assets.
security_policy_applying_assets: i32Number of assets that are in process of updating the security policy on attached resources.
Implementations
Sourceimpl AssetStatus
impl AssetStatus
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = AssetStatus::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = AssetStatus::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = AssetStatus::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_active_assets<T: Into<i32>>(self, v: T) -> Self
pub fn set_active_assets<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_security_policy_applying_assets<T: Into<i32>>(self, v: T) -> Self
pub fn set_security_policy_applying_assets<T: Into<i32>>(self, v: T) -> Self
Sets the value of security_policy_applying_assets.
Example
ⓘ
let x = AssetStatus::new().set_security_policy_applying_assets(42);Trait Implementations
Sourceimpl Clone for AssetStatus
impl Clone for AssetStatus
Sourcefn clone(&self) -> AssetStatus
fn clone(&self) -> AssetStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AssetStatus
impl Debug for AssetStatus
Sourceimpl Default for AssetStatus
impl Default for AssetStatus
Sourcefn default() -> AssetStatus
fn default() -> AssetStatus
Returns the “default value” for a type. Read more
Sourceimpl Message for AssetStatus
impl Message for AssetStatus
Sourceimpl PartialEq for AssetStatus
impl PartialEq for AssetStatus
impl StructuralPartialEq for AssetStatus