#[non_exhaustive]pub struct CreateDataAssetRequest {
pub parent: String,
pub data_asset_id: String,
pub data_asset: Option<DataAsset>,
pub validate_only: bool,
/* private fields */
}Expand description
Request message for creating a data asset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this data asset will be created. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}
data_asset_id: StringOptional. The ID of the data asset to create.
The ID must conform to RFC-1034 and contain only lower-case letters (a-z),
numbers (0-9), or hyphens, with the first character a letter, the last a
letter or a number, and a 63 character maximum. Characters outside of
ASCII are not permitted.
Valid format regex: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$
If not provided, a system generated ID will be used.
data_asset: Option<DataAsset>Required. The data asset to create.
validate_only: boolOptional. Validates the request without actually creating the data asset. Defaults to false.
Implementations
Sourceimpl CreateDataAssetRequest
impl CreateDataAssetRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_data_asset_id<T: Into<String>>(self, v: T) -> Self
pub fn set_data_asset_id<T: Into<String>>(self, v: T) -> Self
Sets the value of data_asset_id.
Example
let x = CreateDataAssetRequest::new().set_data_asset_id("example");Sourcepub fn set_data_asset<T>(self, v: T) -> Self
pub fn set_data_asset<T>(self, v: T) -> Self
Sets the value of data_asset.
Example
use google_cloud_dataplex_v1::model::DataAsset;
let x = CreateDataAssetRequest::new().set_data_asset(DataAsset::default()/* use setters */);Sourcepub fn set_or_clear_data_asset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_data_asset<T>(self, v: Option<T>) -> Self
Sets or clears the value of data_asset.
Example
use google_cloud_dataplex_v1::model::DataAsset;
let x = CreateDataAssetRequest::new().set_or_clear_data_asset(Some(DataAsset::default()/* use setters */));
let x = CreateDataAssetRequest::new().set_or_clear_data_asset(None::<DataAsset>);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateDataAssetRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateDataAssetRequest
impl Clone for CreateDataAssetRequest
Sourcefn clone(&self) -> CreateDataAssetRequest
fn clone(&self) -> CreateDataAssetRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more