#[non_exhaustive]pub struct CreateEntryRequest {
pub parent: String,
pub entry_id: String,
pub entry: Option<Entry>,
/* private fields */
}Expand description
Create Entry request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the parent Entry Group:
projects/{project}/locations/{location}/entryGroups/{entry_group}.
entry_id: StringRequired. Entry identifier. It has to be unique within an Entry Group.
Entries corresponding to Google Cloud resources use an Entry ID format based on full resource names. The format is a full resource name of the resource without the prefix double slashes in the API service name part of the full resource name. This allows retrieval of entries using their associated resource name.
For example, if the full resource name of a resource is
//library.googleapis.com/shelves/shelf1/books/book2,
then the suggested entry_id is
library.googleapis.com/shelves/shelf1/books/book2.
It is also suggested to follow the same convention for entries corresponding to resources from providers or systems other than Google Cloud.
The maximum size of the field is 4000 characters.
entry: Option<Entry>Required. Entry resource.
Implementations
Sourceimpl CreateEntryRequest
impl CreateEntryRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_entry_id<T: Into<String>>(self, v: T) -> Self
pub fn set_entry_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_entry<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_entry<T>(self, v: Option<T>) -> Self