#[non_exhaustive]pub struct DataAttribute {
pub name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub display_name: String,
pub labels: HashMap<String, String>,
pub parent_id: String,
pub attribute_count: i32,
pub etag: String,
pub resource_access_spec: Option<ResourceAccessSpec>,
pub data_access_spec: Option<DataAccessSpec>,
/* private fields */
}Expand description
Denotes one dataAttribute in a dataTaxonomy, for example, PII. DataAttribute resources can be defined in a hierarchy. A single dataAttribute resource can contain specs of multiple types
PII
- ResourceAccessSpec :
- readers :foo@bar.com
- DataAccessSpec :
- readers :bar@foo.comFields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The relative resource name of the dataAttribute, of the form: projects/{project_number}/locations/{location_id}/dataTaxonomies/{dataTaxonomy}/attributes/{data_attribute_id}.
uid: StringOutput only. System generated globally unique ID for the DataAttribute. This ID will be different if the DataAttribute is deleted and re-created with the same name.
create_time: Option<Timestamp>Output only. The time when the DataAttribute was created.
update_time: Option<Timestamp>Output only. The time when the DataAttribute was last updated.
description: StringOptional. Description of the DataAttribute.
display_name: StringOptional. User friendly display name.
labels: HashMap<String, String>Optional. User-defined labels for the DataAttribute.
parent_id: StringOptional. The ID of the parent DataAttribute resource, should belong to the same data taxonomy. Circular dependency in parent chain is not valid. Maximum depth of the hierarchy allowed is 4. [a -> b -> c -> d -> e, depth = 4]
attribute_count: i32Output only. The number of child attributes present for this attribute.
etag: StringThis checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
resource_access_spec: Option<ResourceAccessSpec>Optional. Specified when applied to a resource (eg: Cloud Storage bucket, BigQuery dataset, BigQuery table).
data_access_spec: Option<DataAccessSpec>Optional. Specified when applied to data stored on the resource (eg: rows, columns in BigQuery Tables).
Implementations
Sourceimpl DataAttribute
impl DataAttribute
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DataAttribute::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DataAttribute::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataAttribute::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DataAttribute::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DataAttribute::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataAttribute::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = DataAttribute::new().set_description("example");Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = DataAttribute::new().set_display_name("example");Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_parent_id<T: Into<String>>(self, v: T) -> Self
pub fn set_parent_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_attribute_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_attribute_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of attribute_count.
Example
let x = DataAttribute::new().set_attribute_count(42);Sourcepub fn set_resource_access_spec<T>(self, v: T) -> Selfwhere
T: Into<ResourceAccessSpec>,
pub fn set_resource_access_spec<T>(self, v: T) -> Selfwhere
T: Into<ResourceAccessSpec>,
Sets the value of resource_access_spec.
Example
use google_cloud_dataplex_v1::model::ResourceAccessSpec;
let x = DataAttribute::new().set_resource_access_spec(ResourceAccessSpec::default()/* use setters */);Sourcepub fn set_or_clear_resource_access_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceAccessSpec>,
pub fn set_or_clear_resource_access_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceAccessSpec>,
Sets or clears the value of resource_access_spec.
Example
use google_cloud_dataplex_v1::model::ResourceAccessSpec;
let x = DataAttribute::new().set_or_clear_resource_access_spec(Some(ResourceAccessSpec::default()/* use setters */));
let x = DataAttribute::new().set_or_clear_resource_access_spec(None::<ResourceAccessSpec>);Sourcepub fn set_data_access_spec<T>(self, v: T) -> Selfwhere
T: Into<DataAccessSpec>,
pub fn set_data_access_spec<T>(self, v: T) -> Selfwhere
T: Into<DataAccessSpec>,
Sets the value of data_access_spec.
Example
use google_cloud_dataplex_v1::model::DataAccessSpec;
let x = DataAttribute::new().set_data_access_spec(DataAccessSpec::default()/* use setters */);Sourcepub fn set_or_clear_data_access_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataAccessSpec>,
pub fn set_or_clear_data_access_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataAccessSpec>,
Sets or clears the value of data_access_spec.
Example
use google_cloud_dataplex_v1::model::DataAccessSpec;
let x = DataAttribute::new().set_or_clear_data_access_spec(Some(DataAccessSpec::default()/* use setters */));
let x = DataAttribute::new().set_or_clear_data_access_spec(None::<DataAccessSpec>);Trait Implementations
Sourceimpl Clone for DataAttribute
impl Clone for DataAttribute
Sourcefn clone(&self) -> DataAttribute
fn clone(&self) -> DataAttribute
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataAttribute
impl Debug for DataAttribute
Sourceimpl Default for DataAttribute
impl Default for DataAttribute
Sourcefn default() -> DataAttribute
fn default() -> DataAttribute
Sourceimpl Message for DataAttribute
impl Message for DataAttribute
Sourceimpl PartialEq for DataAttribute
impl PartialEq for DataAttribute
impl StructuralPartialEq for DataAttribute