#[non_exhaustive]pub struct DataAttributeBinding {
pub name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub display_name: String,
pub labels: HashMap<String, String>,
pub etag: String,
pub attributes: Vec<String>,
pub paths: Vec<Path>,
pub resource_reference: Option<ResourceReference>,
/* private fields */
}Expand description
DataAttributeBinding represents binding of attributes to resources. Eg: Bind ‘CustomerInfo’ entity with ‘PII’ attribute.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The relative resource name of the Data Attribute Binding, of the form: projects/{project_number}/locations/{location}/dataAttributeBindings/{data_attribute_binding_id}
uid: StringOutput only. System generated globally unique ID for the DataAttributeBinding. This ID will be different if the DataAttributeBinding is deleted and re-created with the same name.
create_time: Option<Timestamp>Output only. The time when the DataAttributeBinding was created.
update_time: Option<Timestamp>Output only. The time when the DataAttributeBinding was last updated.
description: StringOptional. Description of the DataAttributeBinding.
display_name: StringOptional. User friendly display name.
labels: HashMap<String, String>Optional. User-defined labels for the DataAttributeBinding.
etag: StringThis checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Etags must be used when calling the DeleteDataAttributeBinding and the UpdateDataAttributeBinding method.
attributes: Vec<String>Optional. List of attributes to be associated with the resource, provided in the form: projects/{project}/locations/{location}/dataTaxonomies/{dataTaxonomy}/attributes/{data_attribute_id}
paths: Vec<Path>Optional. The list of paths for items within the associated resource (eg. columns and partitions within a table) along with attribute bindings.
resource_reference: Option<ResourceReference>The reference to the resource that is associated to attributes, or the query to match resources and associate attributes.
Implementations
Sourceimpl DataAttributeBinding
impl DataAttributeBinding
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DataAttributeBinding::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DataAttributeBinding::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataAttributeBinding::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DataAttributeBinding::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DataAttributeBinding::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataAttributeBinding::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = DataAttributeBinding::new().set_description("example");Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = DataAttributeBinding::new().set_display_name("example");Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_attributes<T, V>(self, v: T) -> Self
pub fn set_attributes<T, V>(self, v: T) -> Self
Sets the value of attributes.
Example
let x = DataAttributeBinding::new().set_attributes(["a", "b", "c"]);Sourcepub fn set_resource_reference<T: Into<Option<ResourceReference>>>(
self,
v: T,
) -> Self
pub fn set_resource_reference<T: Into<Option<ResourceReference>>>( self, v: T, ) -> Self
Sets the value of resource_reference.
Note that all the setters affecting resource_reference are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::data_attribute_binding::ResourceReference;
let x = DataAttributeBinding::new().set_resource_reference(Some(ResourceReference::Resource("example".to_string())));Sourcepub fn resource(&self) -> Option<&String>
pub fn resource(&self) -> Option<&String>
The value of resource_reference
if it holds a Resource, None if the field is not set or
holds a different branch.
Sourcepub fn set_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_resource<T: Into<String>>(self, v: T) -> Self
Sets the value of resource_reference
to hold a Resource.
Note that all the setters affecting resource_reference are
mutually exclusive.
Example
let x = DataAttributeBinding::new().set_resource("example");
assert!(x.resource().is_some());Trait Implementations
Sourceimpl Clone for DataAttributeBinding
impl Clone for DataAttributeBinding
Sourcefn clone(&self) -> DataAttributeBinding
fn clone(&self) -> DataAttributeBinding
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataAttributeBinding
impl Debug for DataAttributeBinding
Sourceimpl Default for DataAttributeBinding
impl Default for DataAttributeBinding
Sourcefn default() -> DataAttributeBinding
fn default() -> DataAttributeBinding
Sourceimpl Message for DataAttributeBinding
impl Message for DataAttributeBinding
Sourceimpl PartialEq for DataAttributeBinding
impl PartialEq for DataAttributeBinding
impl StructuralPartialEq for DataAttributeBinding