DataProduct

Struct DataProduct 

#[non_exhaustive]
pub struct DataProduct { pub name: String, pub uid: String, pub display_name: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub etag: String, pub labels: HashMap<String, String>, pub description: String, pub icon: Bytes, pub owner_emails: Vec<String>, pub asset_count: i32, pub access_groups: HashMap<String, AccessGroup>, /* private fields */ }
A data product is a curated collection of data assets, packaged to address specific use cases. It’s a way to manage and share data in a more organized, product-like manner.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Identifier. Resource name of the data product. Format: projects/{project_id_or_number}/locations/{location_id}/dataProducts/{data_product_id}.

uid: String

Output only. System generated unique ID for the data product. This ID will be different if the data product is deleted and re-created with the same name.

display_name: String

Required. User-friendly display name of the data product.

create_time: Option<Timestamp>

Output only. The time at which the data product was created.

update_time: Option<Timestamp>

Output only. The time at which the data product was last updated.

etag: String

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.

labels: HashMap<String, String>

Optional. User-defined labels for the data product.

Example:

{
  "environment": "production",
  "billing": "marketing-department"
}
description: String

Optional. Description of the data product.

icon: Bytes

Optional. Base64 encoded image representing the data product. Max Size: 3.0MiB Expected image dimensions are 512x512 pixels, however the API only performs validation on size of the encoded data. Note: For byte fields, the content of the fields are base64-encoded (which increases the size of the data by 33-36%) when using JSON on the wire.

owner_emails: Vec<String>

Required. Emails of the data product owners.

asset_count: i32

Output only. Number of data assets associated with this data product.

access_groups: HashMap<String, AccessGroup>

Optional. Data product access groups by access group id as key. If data product is used only for packaging data assets, then access groups may be empty. However, if a data product is used for sharing data assets, then at least one access group must be specified.

Example:

{
  "analyst": {
    "id": "analyst",
    "displayName": "Analyst",
    "description": "Access group for analysts",
    "principal": {
      "googleGroup": "analysts@example.com"
    }
  }
}

Implementations

Source

impl DataProduct

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DataProduct::new().set_name("example");
pub fn set_uid<T: Into<String>>(self, v: T) -> Self

Sets the value of uid.

Example
let x = DataProduct::new().set_uid("example");
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = DataProduct::new().set_display_name("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = DataProduct::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = DataProduct::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataProduct::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = DataProduct::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = DataProduct::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataProduct::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = DataProduct::new().set_etag("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = DataProduct::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = DataProduct::new().set_description("example");
pub fn set_icon<T: Into<Bytes>>(self, v: T) -> Self

Sets the value of icon.

Example
let x = DataProduct::new().set_icon(bytes::Bytes::from_static(b"example"));
pub fn set_owner_emails<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of owner_emails.

Example
let x = DataProduct::new().set_owner_emails(["a", "b", "c"]);
pub fn set_asset_count<T: Into<i32>>(self, v: T) -> Self

Sets the value of asset_count.

Example
let x = DataProduct::new().set_asset_count(42);
pub fn set_access_groups<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<AccessGroup>,

Sets the value of access_groups.

Example
use google_cloud_dataplex_v1::model::data_product::AccessGroup;
let x = DataProduct::new().set_access_groups([
    ("key0", AccessGroup::default()/* use setters */),
    ("key1", AccessGroup::default()/* use (different) setters */),
]);