#[non_exhaustive]pub struct DataProfileResult {
pub row_count: i64,
pub profile: Option<Profile>,
pub scanned_data: Option<ScannedData>,
pub post_scan_actions_result: Option<PostScanActionsResult>,
pub catalog_publishing_status: Option<DataScanCatalogPublishingStatus>,
/* private fields */
}Expand description
DataProfileResult defines the output of DataProfileScan. Each field of the table will have field type specific profile result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.row_count: i64Output only. The count of rows scanned.
profile: Option<Profile>Output only. The profile information per field.
scanned_data: Option<ScannedData>Output only. The data scanned for this result.
post_scan_actions_result: Option<PostScanActionsResult>Output only. The result of post scan actions.
catalog_publishing_status: Option<DataScanCatalogPublishingStatus>Output only. The status of publishing the data scan as Dataplex Universal Catalog metadata.
Implementations
Sourceimpl DataProfileResult
impl DataProfileResult
pub fn new() -> Self
Sourcepub fn set_row_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_row_count<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_profile<T>(self, v: T) -> Self
pub fn set_profile<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_profile<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_profile<T>(self, v: Option<T>) -> Self
Sourcepub fn set_scanned_data<T>(self, v: T) -> Selfwhere
T: Into<ScannedData>,
pub fn set_scanned_data<T>(self, v: T) -> Selfwhere
T: Into<ScannedData>,
Sets the value of scanned_data.
Example
ⓘ
use google_cloud_dataplex_v1::model::ScannedData;
let x = DataProfileResult::new().set_scanned_data(ScannedData::default()/* use setters */);Sourcepub fn set_or_clear_scanned_data<T>(self, v: Option<T>) -> Selfwhere
T: Into<ScannedData>,
pub fn set_or_clear_scanned_data<T>(self, v: Option<T>) -> Selfwhere
T: Into<ScannedData>,
Sets or clears the value of scanned_data.
Example
ⓘ
use google_cloud_dataplex_v1::model::ScannedData;
let x = DataProfileResult::new().set_or_clear_scanned_data(Some(ScannedData::default()/* use setters */));
let x = DataProfileResult::new().set_or_clear_scanned_data(None::<ScannedData>);Sourcepub fn set_post_scan_actions_result<T>(self, v: T) -> Selfwhere
T: Into<PostScanActionsResult>,
pub fn set_post_scan_actions_result<T>(self, v: T) -> Selfwhere
T: Into<PostScanActionsResult>,
Sets the value of post_scan_actions_result.
Example
ⓘ
use google_cloud_dataplex_v1::model::data_profile_result::PostScanActionsResult;
let x = DataProfileResult::new().set_post_scan_actions_result(PostScanActionsResult::default()/* use setters */);Sourcepub fn set_or_clear_post_scan_actions_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<PostScanActionsResult>,
pub fn set_or_clear_post_scan_actions_result<T>(self, v: Option<T>) -> Selfwhere
T: Into<PostScanActionsResult>,
Sets or clears the value of post_scan_actions_result.
Example
ⓘ
use google_cloud_dataplex_v1::model::data_profile_result::PostScanActionsResult;
let x = DataProfileResult::new().set_or_clear_post_scan_actions_result(Some(PostScanActionsResult::default()/* use setters */));
let x = DataProfileResult::new().set_or_clear_post_scan_actions_result(None::<PostScanActionsResult>);Sourcepub fn set_catalog_publishing_status<T>(self, v: T) -> Selfwhere
T: Into<DataScanCatalogPublishingStatus>,
pub fn set_catalog_publishing_status<T>(self, v: T) -> Selfwhere
T: Into<DataScanCatalogPublishingStatus>,
Sets the value of catalog_publishing_status.
Example
ⓘ
use google_cloud_dataplex_v1::model::DataScanCatalogPublishingStatus;
let x = DataProfileResult::new().set_catalog_publishing_status(DataScanCatalogPublishingStatus::default()/* use setters */);Sourcepub fn set_or_clear_catalog_publishing_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataScanCatalogPublishingStatus>,
pub fn set_or_clear_catalog_publishing_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataScanCatalogPublishingStatus>,
Sets or clears the value of catalog_publishing_status.
Example
ⓘ
use google_cloud_dataplex_v1::model::DataScanCatalogPublishingStatus;
let x = DataProfileResult::new().set_or_clear_catalog_publishing_status(Some(DataScanCatalogPublishingStatus::default()/* use setters */));
let x = DataProfileResult::new().set_or_clear_catalog_publishing_status(None::<DataScanCatalogPublishingStatus>);Trait Implementations
Sourceimpl Clone for DataProfileResult
impl Clone for DataProfileResult
Sourcefn clone(&self) -> DataProfileResult
fn clone(&self) -> DataProfileResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataProfileResult
impl Debug for DataProfileResult
Sourceimpl Default for DataProfileResult
impl Default for DataProfileResult
Sourcefn default() -> DataProfileResult
fn default() -> DataProfileResult
Returns the “default value” for a type. Read more
Sourceimpl Message for DataProfileResult
impl Message for DataProfileResult
Sourceimpl PartialEq for DataProfileResult
impl PartialEq for DataProfileResult
impl StructuralPartialEq for DataProfileResult