#[non_exhaustive]pub struct DataProfileSpec {
pub sampling_percent: f32,
pub row_filter: String,
pub post_scan_actions: Option<PostScanActions>,
pub include_fields: Option<SelectedFields>,
pub exclude_fields: Option<SelectedFields>,
pub catalog_publishing_enabled: bool,
pub mode: Mode,
/* private fields */
}Expand description
DataProfileScan related setting.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sampling_percent: f32Optional. The percentage of the records to be selected from the dataset for DataScan.
- Value can range between 0.0 and 100.0 with up to 3 significant decimal digits.
- Sampling is not applied if
sampling_percentis not specified, 0 or
row_filter: StringOptional. A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in BigQuery standard SQL syntax. Example: col1 >= 0 AND col2 < 10
post_scan_actions: Option<PostScanActions>Optional. Actions to take upon job completion..
include_fields: Option<SelectedFields>Optional. The fields to include in data profile.
If not specified, all fields at the time of profile scan job execution are
included, except for ones listed in exclude_fields.
exclude_fields: Option<SelectedFields>Optional. The fields to exclude from data profile.
If specified, the fields will be excluded from data profile, regardless of
include_fields value.
catalog_publishing_enabled: boolOptional. If set, the latest DataScan job result will be published as Dataplex Universal Catalog metadata.
mode: ModeOptional. The execution mode for the profile scan.
Implementations
Sourceimpl DataProfileSpec
impl DataProfileSpec
Sourcepub fn set_sampling_percent<T: Into<f32>>(self, v: T) -> Self
pub fn set_sampling_percent<T: Into<f32>>(self, v: T) -> Self
Sets the value of sampling_percent.
Example
let x = DataProfileSpec::new().set_sampling_percent(42.0);Sourcepub fn set_row_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_row_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_post_scan_actions<T>(self, v: T) -> Selfwhere
T: Into<PostScanActions>,
pub fn set_post_scan_actions<T>(self, v: T) -> Selfwhere
T: Into<PostScanActions>,
Sets the value of post_scan_actions.
Example
use google_cloud_dataplex_v1::model::data_profile_spec::PostScanActions;
let x = DataProfileSpec::new().set_post_scan_actions(PostScanActions::default()/* use setters */);Sourcepub fn set_or_clear_post_scan_actions<T>(self, v: Option<T>) -> Selfwhere
T: Into<PostScanActions>,
pub fn set_or_clear_post_scan_actions<T>(self, v: Option<T>) -> Selfwhere
T: Into<PostScanActions>,
Sets or clears the value of post_scan_actions.
Example
use google_cloud_dataplex_v1::model::data_profile_spec::PostScanActions;
let x = DataProfileSpec::new().set_or_clear_post_scan_actions(Some(PostScanActions::default()/* use setters */));
let x = DataProfileSpec::new().set_or_clear_post_scan_actions(None::<PostScanActions>);Sourcepub fn set_include_fields<T>(self, v: T) -> Selfwhere
T: Into<SelectedFields>,
pub fn set_include_fields<T>(self, v: T) -> Selfwhere
T: Into<SelectedFields>,
Sets the value of include_fields.
Example
use google_cloud_dataplex_v1::model::data_profile_spec::SelectedFields;
let x = DataProfileSpec::new().set_include_fields(SelectedFields::default()/* use setters */);Sourcepub fn set_or_clear_include_fields<T>(self, v: Option<T>) -> Selfwhere
T: Into<SelectedFields>,
pub fn set_or_clear_include_fields<T>(self, v: Option<T>) -> Selfwhere
T: Into<SelectedFields>,
Sets or clears the value of include_fields.
Example
use google_cloud_dataplex_v1::model::data_profile_spec::SelectedFields;
let x = DataProfileSpec::new().set_or_clear_include_fields(Some(SelectedFields::default()/* use setters */));
let x = DataProfileSpec::new().set_or_clear_include_fields(None::<SelectedFields>);Sourcepub fn set_exclude_fields<T>(self, v: T) -> Selfwhere
T: Into<SelectedFields>,
pub fn set_exclude_fields<T>(self, v: T) -> Selfwhere
T: Into<SelectedFields>,
Sets the value of exclude_fields.
Example
use google_cloud_dataplex_v1::model::data_profile_spec::SelectedFields;
let x = DataProfileSpec::new().set_exclude_fields(SelectedFields::default()/* use setters */);Sourcepub fn set_or_clear_exclude_fields<T>(self, v: Option<T>) -> Selfwhere
T: Into<SelectedFields>,
pub fn set_or_clear_exclude_fields<T>(self, v: Option<T>) -> Selfwhere
T: Into<SelectedFields>,
Sets or clears the value of exclude_fields.
Example
use google_cloud_dataplex_v1::model::data_profile_spec::SelectedFields;
let x = DataProfileSpec::new().set_or_clear_exclude_fields(Some(SelectedFields::default()/* use setters */));
let x = DataProfileSpec::new().set_or_clear_exclude_fields(None::<SelectedFields>);Sourcepub fn set_catalog_publishing_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_catalog_publishing_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of catalog_publishing_enabled.
Example
let x = DataProfileSpec::new().set_catalog_publishing_enabled(true);Trait Implementations
Sourceimpl Clone for DataProfileSpec
impl Clone for DataProfileSpec
Sourcefn clone(&self) -> DataProfileSpec
fn clone(&self) -> DataProfileSpec
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataProfileSpec
impl Debug for DataProfileSpec
Sourceimpl Default for DataProfileSpec
impl Default for DataProfileSpec
Sourcefn default() -> DataProfileSpec
fn default() -> DataProfileSpec
Sourceimpl Message for DataProfileSpec
impl Message for DataProfileSpec
Sourceimpl PartialEq for DataProfileSpec
impl PartialEq for DataProfileSpec
impl StructuralPartialEq for DataProfileSpec