#[non_exhaustive]pub struct DataQualityRuleTemplate {
pub name: String,
pub dimension: String,
pub sql_collection: Vec<Sql>,
pub input_parameters: HashMap<String, ParameterDescription>,
pub capabilities: Vec<String>,
/* private fields */
}Expand description
DataQualityRuleTemplate represents a template which can be reused across multiple data quality rules.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The name of the rule template in the format:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}
dimension: StringOutput only. The dimension a rule template belongs to. Rule level results are also aggregated at the dimension level.
sql_collection: Vec<Sql>Output only. Collection of SQLs for data quality rules. Currently only one SQL is supported.
input_parameters: HashMap<String, ParameterDescription>Output only. Description for input parameters
capabilities: Vec<String>Output only. A list of features or properties supported by this rule template.
Implementations
Sourceimpl DataQualityRuleTemplate
impl DataQualityRuleTemplate
Sourcepub fn set_dimension<T: Into<String>>(self, v: T) -> Self
pub fn set_dimension<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_sql_collection<T, V>(self, v: T) -> Self
pub fn set_sql_collection<T, V>(self, v: T) -> Self
Sets the value of sql_collection.
Example
ⓘ
use google_cloud_dataplex_v1::model::data_quality_rule_template::Sql;
let x = DataQualityRuleTemplate::new()
.set_sql_collection([
Sql::default()/* use setters */,
Sql::default()/* use (different) setters */,
]);Sourcepub fn set_input_parameters<T, K, V>(self, v: T) -> Self
pub fn set_input_parameters<T, K, V>(self, v: T) -> Self
Sets the value of input_parameters.
Example
ⓘ
use google_cloud_dataplex_v1::model::data_quality_rule_template::ParameterDescription;
let x = DataQualityRuleTemplate::new().set_input_parameters([
("key0", ParameterDescription::default()/* use setters */),
("key1", ParameterDescription::default()/* use (different) setters */),
]);Sourcepub fn set_capabilities<T, V>(self, v: T) -> Self
pub fn set_capabilities<T, V>(self, v: T) -> Self
Sets the value of capabilities.
Example
ⓘ
let x = DataQualityRuleTemplate::new().set_capabilities(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for DataQualityRuleTemplate
impl Clone for DataQualityRuleTemplate
Sourcefn clone(&self) -> DataQualityRuleTemplate
fn clone(&self) -> DataQualityRuleTemplate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataQualityRuleTemplate
impl Debug for DataQualityRuleTemplate
Sourceimpl Default for DataQualityRuleTemplate
impl Default for DataQualityRuleTemplate
Sourcefn default() -> DataQualityRuleTemplate
fn default() -> DataQualityRuleTemplate
Returns the “default value” for a type. Read more
Sourceimpl Message for DataQualityRuleTemplate
impl Message for DataQualityRuleTemplate
Sourceimpl PartialEq for DataQualityRuleTemplate
impl PartialEq for DataQualityRuleTemplate
impl StructuralPartialEq for DataQualityRuleTemplate