DataScan

Struct DataScan 

#[non_exhaustive]
pub struct DataScan {
Show 15 fields pub name: String, pub uid: String, pub description: String, pub display_name: String, pub labels: HashMap<String, String>, pub state: State, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub data: Option<DataSource>, pub execution_spec: Option<ExecutionSpec>, pub execution_status: Option<ExecutionStatus>, pub type: DataScanType, pub execution_identity: Option<ExecutionIdentity>, pub spec: Option<Spec>, pub result: Option<Result>, /* private fields */
}
Represents a user-visible job which provides the insights for the related data source.

For example:

  • Data quality: generates queries based on the rules and runs against the data to get data quality check results. For more information, see Auto data quality overview.
  • Data profile: analyzes the data in tables and generates insights about the structure, content and relationships (such as null percent, cardinality, min/max/mean, etc). For more information, see About data profiling.
  • Data discovery: scans data in Cloud Storage buckets to extract and then catalog metadata. For more information, see Discover and catalog Cloud Storage data.
  • Data documentation: analyzes the table or dataset metadata and generates insights. For tables, insights include descriptions and sample SQL queries. For datasets, insights include descriptions, schema relationships and sample SQL queries. For more information, see Generate data insights in BigQuery.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. Identifier. The relative resource name of the scan, of the form: projects/{project}/locations/{location_id}/dataScans/{datascan_id}, where project refers to a project_id or project_number and location_id refers to a Google Cloud region.

uid: String

Output only. System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.

description: String

Optional. Description of the scan.

  • Must be between 1-1024 characters.
display_name: String

Optional. User friendly display name.

  • Must be between 1-256 characters.
labels: HashMap<String, String>

Optional. User-defined labels for the scan.

state: State

Output only. Current state of the DataScan.

create_time: Option<Timestamp>

Output only. The time when the scan was created.

update_time: Option<Timestamp>

Output only. The time when the scan was last updated.

data: Option<DataSource>

Required. The data source for DataScan.

execution_spec: Option<ExecutionSpec>

Optional. DataScan execution settings.

If not specified, the fields in it will use their default values.

execution_status: Option<ExecutionStatus>

Output only. Status of the data scan execution.

type: DataScanType

Output only. The type of DataScan.

execution_identity: Option<ExecutionIdentity>

Optional. Immutable. The identity to run the datascan. If not specified, defaults to the Dataplex Service Agent.

spec: Option<Spec>

Data scan related setting. The settings are required and immutable. After you configure the settings for one type of data scan, you can’t change the data scan to a different type of data scan.

result: Option<Result>

The result of the data scan.

Implementations

Source

impl DataScan

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DataScan::new().set_name(format!("projects/{project_id}/locations/{location_id}/dataScans/{data_scan_id}"));
pub fn set_uid<T: Into<String>>(self, v: T) -> Self

Sets the value of uid.

Example
let x = DataScan::new().set_uid("example");
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = DataScan::new().set_description("example");
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = DataScan::new().set_display_name("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = DataScan::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_dataplex_v1::model::State;
let x0 = DataScan::new().set_state(State::Active);
let x1 = DataScan::new().set_state(State::Creating);
let x2 = DataScan::new().set_state(State::Deleting);
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = DataScan::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = DataScan::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataScan::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = DataScan::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = DataScan::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataScan::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_data<T>(self, v: T) -> Self
where T: Into<DataSource>,

Sets the value of data.

Example
use google_cloud_dataplex_v1::model::DataSource;
let x = DataScan::new().set_data(DataSource::default()/* use setters */);
pub fn set_or_clear_data<T>(self, v: Option<T>) -> Self
where T: Into<DataSource>,

Sets or clears the value of data.

Example
use google_cloud_dataplex_v1::model::DataSource;
let x = DataScan::new().set_or_clear_data(Some(DataSource::default()/* use setters */));
let x = DataScan::new().set_or_clear_data(None::<DataSource>);
pub fn set_execution_spec<T>(self, v: T) -> Self
where T: Into<ExecutionSpec>,

Sets the value of execution_spec.

Example
use google_cloud_dataplex_v1::model::data_scan::ExecutionSpec;
let x = DataScan::new().set_execution_spec(ExecutionSpec::default()/* use setters */);
pub fn set_or_clear_execution_spec<T>(self, v: Option<T>) -> Self
where T: Into<ExecutionSpec>,

Sets or clears the value of execution_spec.

Example
use google_cloud_dataplex_v1::model::data_scan::ExecutionSpec;
let x = DataScan::new().set_or_clear_execution_spec(Some(ExecutionSpec::default()/* use setters */));
let x = DataScan::new().set_or_clear_execution_spec(None::<ExecutionSpec>);
pub fn set_execution_status<T>(self, v: T) -> Self

Sets the value of execution_status.

Example
use google_cloud_dataplex_v1::model::data_scan::ExecutionStatus;
let x = DataScan::new().set_execution_status(ExecutionStatus::default()/* use setters */);
pub fn set_or_clear_execution_status<T>(self, v: Option<T>) -> Self

Sets or clears the value of execution_status.

Example
use google_cloud_dataplex_v1::model::data_scan::ExecutionStatus;
let x = DataScan::new().set_or_clear_execution_status(Some(ExecutionStatus::default()/* use setters */));
let x = DataScan::new().set_or_clear_execution_status(None::<ExecutionStatus>);
pub fn set_type<T: Into<DataScanType>>(self, v: T) -> Self

Sets the value of r#type.

Example
use google_cloud_dataplex_v1::model::DataScanType;
let x0 = DataScan::new().set_type(DataScanType::DataQuality);
let x1 = DataScan::new().set_type(DataScanType::DataProfile);
let x2 = DataScan::new().set_type(DataScanType::DataDiscovery);
pub fn set_execution_identity<T>(self, v: T) -> Self

Sets the value of execution_identity.

Example
use google_cloud_dataplex_v1::model::ExecutionIdentity;
let x = DataScan::new().set_execution_identity(ExecutionIdentity::default()/* use setters */);
pub fn set_or_clear_execution_identity<T>(self, v: Option<T>) -> Self

Sets or clears the value of execution_identity.

Example
use google_cloud_dataplex_v1::model::ExecutionIdentity;
let x = DataScan::new().set_or_clear_execution_identity(Some(ExecutionIdentity::default()/* use setters */));
let x = DataScan::new().set_or_clear_execution_identity(None::<ExecutionIdentity>);
pub fn set_spec<T: Into<Option<Spec>>>(self, v: T) -> Self

Sets the value of spec.

Note that all the setters affecting spec are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataQualitySpec;
let x = DataScan::new().set_spec(Some(
    google_cloud_dataplex_v1::model::data_scan::Spec::DataQualitySpec(DataQualitySpec::default().into())));
pub fn data_quality_spec(&self) -> Option<&Box<DataQualitySpec>>

The value of spec if it holds a DataQualitySpec, None if the field is not set or holds a different branch.

pub fn set_data_quality_spec<T: Into<Box<DataQualitySpec>>>(self, v: T) -> Self

Sets the value of spec to hold a DataQualitySpec.

Note that all the setters affecting spec are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataQualitySpec;
let x = DataScan::new().set_data_quality_spec(DataQualitySpec::default()/* use setters */);
assert!(x.data_quality_spec().is_some());
assert!(x.data_profile_spec().is_none());
assert!(x.data_discovery_spec().is_none());
assert!(x.data_documentation_spec().is_none());
pub fn data_profile_spec(&self) -> Option<&Box<DataProfileSpec>>

The value of spec if it holds a DataProfileSpec, None if the field is not set or holds a different branch.

pub fn set_data_profile_spec<T: Into<Box<DataProfileSpec>>>(self, v: T) -> Self

Sets the value of spec to hold a DataProfileSpec.

Note that all the setters affecting spec are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataProfileSpec;
let x = DataScan::new().set_data_profile_spec(DataProfileSpec::default()/* use setters */);
assert!(x.data_profile_spec().is_some());
assert!(x.data_quality_spec().is_none());
assert!(x.data_discovery_spec().is_none());
assert!(x.data_documentation_spec().is_none());
pub fn data_discovery_spec(&self) -> Option<&Box<DataDiscoverySpec>>

The value of spec if it holds a DataDiscoverySpec, None if the field is not set or holds a different branch.

pub fn set_data_discovery_spec<T: Into<Box<DataDiscoverySpec>>>( self, v: T, ) -> Self

Sets the value of spec to hold a DataDiscoverySpec.

Note that all the setters affecting spec are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataDiscoverySpec;
let x = DataScan::new().set_data_discovery_spec(DataDiscoverySpec::default()/* use setters */);
assert!(x.data_discovery_spec().is_some());
assert!(x.data_quality_spec().is_none());
assert!(x.data_profile_spec().is_none());
assert!(x.data_documentation_spec().is_none());
pub fn data_documentation_spec(&self) -> Option<&Box<DataDocumentationSpec>>

The value of spec if it holds a DataDocumentationSpec, None if the field is not set or holds a different branch.

pub fn set_data_documentation_spec<T: Into<Box<DataDocumentationSpec>>>( self, v: T, ) -> Self

Sets the value of spec to hold a DataDocumentationSpec.

Note that all the setters affecting spec are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataDocumentationSpec;
let x = DataScan::new().set_data_documentation_spec(DataDocumentationSpec::default()/* use setters */);
assert!(x.data_documentation_spec().is_some());
assert!(x.data_quality_spec().is_none());
assert!(x.data_profile_spec().is_none());
assert!(x.data_discovery_spec().is_none());
pub fn set_result<T: Into<Option<Result>>>(self, v: T) -> Self

Sets the value of result.

Note that all the setters affecting result are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataQualityResult;
let x = DataScan::new().set_result(Some(
    google_cloud_dataplex_v1::model::data_scan::Result::DataQualityResult(DataQualityResult::default().into())));
pub fn data_quality_result(&self) -> Option<&Box<DataQualityResult>>

The value of result if it holds a DataQualityResult, None if the field is not set or holds a different branch.

pub fn set_data_quality_result<T: Into<Box<DataQualityResult>>>( self, v: T, ) -> Self

Sets the value of result to hold a DataQualityResult.

Note that all the setters affecting result are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataQualityResult;
let x = DataScan::new().set_data_quality_result(DataQualityResult::default()/* use setters */);
assert!(x.data_quality_result().is_some());
assert!(x.data_profile_result().is_none());
assert!(x.data_discovery_result().is_none());
assert!(x.data_documentation_result().is_none());
pub fn data_profile_result(&self) -> Option<&Box<DataProfileResult>>

The value of result if it holds a DataProfileResult, None if the field is not set or holds a different branch.

pub fn set_data_profile_result<T: Into<Box<DataProfileResult>>>( self, v: T, ) -> Self

Sets the value of result to hold a DataProfileResult.

Note that all the setters affecting result are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataProfileResult;
let x = DataScan::new().set_data_profile_result(DataProfileResult::default()/* use setters */);
assert!(x.data_profile_result().is_some());
assert!(x.data_quality_result().is_none());
assert!(x.data_discovery_result().is_none());
assert!(x.data_documentation_result().is_none());
pub fn data_discovery_result(&self) -> Option<&Box<DataDiscoveryResult>>

The value of result if it holds a DataDiscoveryResult, None if the field is not set or holds a different branch.

pub fn set_data_discovery_result<T: Into<Box<DataDiscoveryResult>>>( self, v: T, ) -> Self

Sets the value of result to hold a DataDiscoveryResult.

Note that all the setters affecting result are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataDiscoveryResult;
let x = DataScan::new().set_data_discovery_result(DataDiscoveryResult::default()/* use setters */);
assert!(x.data_discovery_result().is_some());
assert!(x.data_quality_result().is_none());
assert!(x.data_profile_result().is_none());
assert!(x.data_documentation_result().is_none());
pub fn data_documentation_result(&self) -> Option<&Box<DataDocumentationResult>>

The value of result if it holds a DataDocumentationResult, None if the field is not set or holds a different branch.

pub fn set_data_documentation_result<T: Into<Box<DataDocumentationResult>>>( self, v: T, ) -> Self

Sets the value of result to hold a DataDocumentationResult.

Note that all the setters affecting result are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::DataDocumentationResult;
let x = DataScan::new().set_data_documentation_result(DataDocumentationResult::default()/* use setters */);
assert!(x.data_documentation_result().is_some());
assert!(x.data_quality_result().is_none());
assert!(x.data_profile_result().is_none());
assert!(x.data_discovery_result().is_none());