#[non_exhaustive]pub struct DataScanCatalogPublishingStatus {
pub state: State,
/* private fields */
}Expand description
The status of publishing the data scan result as Dataplex Universal Catalog metadata. Multiple DataScan log events may exist, each with different publishing information depending on the type of publishing triggered.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: StateOutput only. Execution state for publishing.
Implementations
Sourceimpl DataScanCatalogPublishingStatus
impl DataScanCatalogPublishingStatus
pub fn new() -> Self
Sourcepub fn set_state<T: Into<State>>(self, v: T) -> Self
pub fn set_state<T: Into<State>>(self, v: T) -> Self
Sets the value of state.
Example
ⓘ
use google_cloud_dataplex_v1::model::data_scan_catalog_publishing_status::State;
let x0 = DataScanCatalogPublishingStatus::new().set_state(State::Succeeded);
let x1 = DataScanCatalogPublishingStatus::new().set_state(State::Failed);
let x2 = DataScanCatalogPublishingStatus::new().set_state(State::Skipped);Trait Implementations
Sourceimpl Clone for DataScanCatalogPublishingStatus
impl Clone for DataScanCatalogPublishingStatus
Sourcefn clone(&self) -> DataScanCatalogPublishingStatus
fn clone(&self) -> DataScanCatalogPublishingStatus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for DataScanCatalogPublishingStatus
impl Default for DataScanCatalogPublishingStatus
Sourcefn default() -> DataScanCatalogPublishingStatus
fn default() -> DataScanCatalogPublishingStatus
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for DataScanCatalogPublishingStatus
impl PartialEq for DataScanCatalogPublishingStatus
Sourcefn eq(&self, other: &DataScanCatalogPublishingStatus) -> bool
fn eq(&self, other: &DataScanCatalogPublishingStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DataScanCatalogPublishingStatus