#[non_exhaustive]pub struct DataScanJob {
pub name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub partial_failure_message: String,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub state: State,
pub message: String,
pub type: DataScanType,
pub spec: Option<Spec>,
pub result: Option<Result>,
/* private fields */
}Expand description
A DataScanJob represents an instance of DataScan execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. The relative resource name of the DataScanJob, of
the form:
projects/{project}/locations/{location_id}/dataScans/{datascan_id}/jobs/{job_id},
where project refers to a project_id or project_number and
location_id refers to a Google Cloud region.
uid: StringOutput only. System generated globally unique ID for the DataScanJob.
create_time: Option<Timestamp>Output only. The time when the DataScanJob was created.
partial_failure_message: StringOutput only. A message indicating partial failure details.
start_time: Option<Timestamp>Output only. The time when the DataScanJob was started.
end_time: Option<Timestamp>Output only. The time when the DataScanJob ended.
state: StateOutput only. Execution state for the DataScanJob.
message: StringOutput only. Additional information about the current state.
type: DataScanTypeOutput only. The type of the parent DataScan.
spec: Option<Spec>Data scan related setting.
result: Option<Result>The result of the data scan.
Implementations
Sourceimpl DataScanJob
impl DataScanJob
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DataScanJob::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DataScanJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataScanJob::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_partial_failure_message<T: Into<String>>(self, v: T) -> Self
pub fn set_partial_failure_message<T: Into<String>>(self, v: T) -> Self
Sets the value of partial_failure_message.
Example
let x = DataScanJob::new().set_partial_failure_message("example");Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = DataScanJob::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = DataScanJob::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = DataScanJob::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_message<T: Into<String>>(self, v: T) -> Self
pub fn set_message<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_type<T: Into<DataScanType>>(self, v: T) -> Self
pub fn set_type<T: Into<DataScanType>>(self, v: T) -> Self
Sourcepub fn set_spec<T: Into<Option<Spec>>>(self, v: T) -> Self
pub fn set_spec<T: Into<Option<Spec>>>(self, v: T) -> Self
Sets the value of spec.
Note that all the setters affecting spec are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::DataQualitySpec;
let x = DataScanJob::new().set_spec(Some(
google_cloud_dataplex_v1::model::data_scan_job::Spec::DataQualitySpec(DataQualitySpec::default().into())));Sourcepub fn data_quality_spec(&self) -> Option<&Box<DataQualitySpec>>
pub fn data_quality_spec(&self) -> Option<&Box<DataQualitySpec>>
The value of spec
if it holds a DataQualitySpec, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_quality_spec<T: Into<Box<DataQualitySpec>>>(self, v: T) -> Self
pub fn set_data_quality_spec<T: Into<Box<DataQualitySpec>>>(self, v: T) -> Self
Sets the value of spec
to hold a DataQualitySpec.
Note that all the setters affecting spec are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::DataQualitySpec;
let x = DataScanJob::new().set_data_quality_spec(DataQualitySpec::default()/* use setters */);
assert!(x.data_quality_spec().is_some());
assert!(x.data_profile_spec().is_none());
assert!(x.data_discovery_spec().is_none());
assert!(x.data_documentation_spec().is_none());Sourcepub fn data_profile_spec(&self) -> Option<&Box<DataProfileSpec>>
pub fn data_profile_spec(&self) -> Option<&Box<DataProfileSpec>>
The value of spec
if it holds a DataProfileSpec, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_profile_spec<T: Into<Box<DataProfileSpec>>>(self, v: T) -> Self
pub fn set_data_profile_spec<T: Into<Box<DataProfileSpec>>>(self, v: T) -> Self
Sets the value of spec
to hold a DataProfileSpec.
Note that all the setters affecting spec are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::DataProfileSpec;
let x = DataScanJob::new().set_data_profile_spec(DataProfileSpec::default()/* use setters */);
assert!(x.data_profile_spec().is_some());
assert!(x.data_quality_spec().is_none());
assert!(x.data_discovery_spec().is_none());
assert!(x.data_documentation_spec().is_none());Sourcepub fn data_discovery_spec(&self) -> Option<&Box<DataDiscoverySpec>>
pub fn data_discovery_spec(&self) -> Option<&Box<DataDiscoverySpec>>
The value of spec
if it holds a DataDiscoverySpec, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_discovery_spec<T: Into<Box<DataDiscoverySpec>>>(
self,
v: T,
) -> Self
pub fn set_data_discovery_spec<T: Into<Box<DataDiscoverySpec>>>( self, v: T, ) -> Self
Sets the value of spec
to hold a DataDiscoverySpec.
Note that all the setters affecting spec are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::DataDiscoverySpec;
let x = DataScanJob::new().set_data_discovery_spec(DataDiscoverySpec::default()/* use setters */);
assert!(x.data_discovery_spec().is_some());
assert!(x.data_quality_spec().is_none());
assert!(x.data_profile_spec().is_none());
assert!(x.data_documentation_spec().is_none());Sourcepub fn data_documentation_spec(&self) -> Option<&Box<DataDocumentationSpec>>
pub fn data_documentation_spec(&self) -> Option<&Box<DataDocumentationSpec>>
The value of spec
if it holds a DataDocumentationSpec, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_documentation_spec<T: Into<Box<DataDocumentationSpec>>>(
self,
v: T,
) -> Self
pub fn set_data_documentation_spec<T: Into<Box<DataDocumentationSpec>>>( self, v: T, ) -> Self
Sets the value of spec
to hold a DataDocumentationSpec.
Note that all the setters affecting spec are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::DataDocumentationSpec;
let x = DataScanJob::new().set_data_documentation_spec(DataDocumentationSpec::default()/* use setters */);
assert!(x.data_documentation_spec().is_some());
assert!(x.data_quality_spec().is_none());
assert!(x.data_profile_spec().is_none());
assert!(x.data_discovery_spec().is_none());Sourcepub fn set_result<T: Into<Option<Result>>>(self, v: T) -> Self
pub fn set_result<T: Into<Option<Result>>>(self, v: T) -> Self
Sets the value of result.
Note that all the setters affecting result are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::DataQualityResult;
let x = DataScanJob::new().set_result(Some(
google_cloud_dataplex_v1::model::data_scan_job::Result::DataQualityResult(DataQualityResult::default().into())));Sourcepub fn data_quality_result(&self) -> Option<&Box<DataQualityResult>>
pub fn data_quality_result(&self) -> Option<&Box<DataQualityResult>>
The value of result
if it holds a DataQualityResult, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_quality_result<T: Into<Box<DataQualityResult>>>(
self,
v: T,
) -> Self
pub fn set_data_quality_result<T: Into<Box<DataQualityResult>>>( self, v: T, ) -> Self
Sets the value of result
to hold a DataQualityResult.
Note that all the setters affecting result are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::DataQualityResult;
let x = DataScanJob::new().set_data_quality_result(DataQualityResult::default()/* use setters */);
assert!(x.data_quality_result().is_some());
assert!(x.data_profile_result().is_none());
assert!(x.data_discovery_result().is_none());
assert!(x.data_documentation_result().is_none());Sourcepub fn data_profile_result(&self) -> Option<&Box<DataProfileResult>>
pub fn data_profile_result(&self) -> Option<&Box<DataProfileResult>>
The value of result
if it holds a DataProfileResult, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_profile_result<T: Into<Box<DataProfileResult>>>(
self,
v: T,
) -> Self
pub fn set_data_profile_result<T: Into<Box<DataProfileResult>>>( self, v: T, ) -> Self
Sets the value of result
to hold a DataProfileResult.
Note that all the setters affecting result are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::DataProfileResult;
let x = DataScanJob::new().set_data_profile_result(DataProfileResult::default()/* use setters */);
assert!(x.data_profile_result().is_some());
assert!(x.data_quality_result().is_none());
assert!(x.data_discovery_result().is_none());
assert!(x.data_documentation_result().is_none());Sourcepub fn data_discovery_result(&self) -> Option<&Box<DataDiscoveryResult>>
pub fn data_discovery_result(&self) -> Option<&Box<DataDiscoveryResult>>
The value of result
if it holds a DataDiscoveryResult, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_discovery_result<T: Into<Box<DataDiscoveryResult>>>(
self,
v: T,
) -> Self
pub fn set_data_discovery_result<T: Into<Box<DataDiscoveryResult>>>( self, v: T, ) -> Self
Sets the value of result
to hold a DataDiscoveryResult.
Note that all the setters affecting result are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::DataDiscoveryResult;
let x = DataScanJob::new().set_data_discovery_result(DataDiscoveryResult::default()/* use setters */);
assert!(x.data_discovery_result().is_some());
assert!(x.data_quality_result().is_none());
assert!(x.data_profile_result().is_none());
assert!(x.data_documentation_result().is_none());Sourcepub fn data_documentation_result(&self) -> Option<&Box<DataDocumentationResult>>
pub fn data_documentation_result(&self) -> Option<&Box<DataDocumentationResult>>
The value of result
if it holds a DataDocumentationResult, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_documentation_result<T: Into<Box<DataDocumentationResult>>>(
self,
v: T,
) -> Self
pub fn set_data_documentation_result<T: Into<Box<DataDocumentationResult>>>( self, v: T, ) -> Self
Sets the value of result
to hold a DataDocumentationResult.
Note that all the setters affecting result are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::DataDocumentationResult;
let x = DataScanJob::new().set_data_documentation_result(DataDocumentationResult::default()/* use setters */);
assert!(x.data_documentation_result().is_some());
assert!(x.data_quality_result().is_none());
assert!(x.data_profile_result().is_none());
assert!(x.data_discovery_result().is_none());Trait Implementations
Sourceimpl Clone for DataScanJob
impl Clone for DataScanJob
Sourcefn clone(&self) -> DataScanJob
fn clone(&self) -> DataScanJob
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataScanJob
impl Debug for DataScanJob
Sourceimpl Default for DataScanJob
impl Default for DataScanJob
Sourcefn default() -> DataScanJob
fn default() -> DataScanJob
Sourceimpl Message for DataScanJob
impl Message for DataScanJob
Sourceimpl PartialEq for DataScanJob
impl PartialEq for DataScanJob
impl StructuralPartialEq for DataScanJob