#[non_exhaustive]pub struct DataTaxonomy {
pub name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub display_name: String,
pub labels: HashMap<String, String>,
pub attribute_count: i32,
pub etag: String,
pub class_count: i32,
/* private fields */
}Expand description
DataTaxonomy represents a set of hierarchical DataAttributes resources, grouped with a common theme Eg: ‘SensitiveDataTaxonomy’ can have attributes to manage PII data. It is defined at project level.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The relative resource name of the DataTaxonomy, of the form: projects/{project_number}/locations/{location_id}/dataTaxonomies/{data_taxonomy_id}.
uid: StringOutput only. System generated globally unique ID for the dataTaxonomy. This ID will be different if the DataTaxonomy is deleted and re-created with the same name.
create_time: Option<Timestamp>Output only. The time when the DataTaxonomy was created.
update_time: Option<Timestamp>Output only. The time when the DataTaxonomy was last updated.
description: StringOptional. Description of the DataTaxonomy.
display_name: StringOptional. User friendly display name.
labels: HashMap<String, String>Optional. User-defined labels for the DataTaxonomy.
attribute_count: i32Output only. The number of attributes in the DataTaxonomy.
etag: StringThis checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
class_count: i32Output only. The number of classes in the DataTaxonomy.
Implementations
Sourceimpl DataTaxonomy
impl DataTaxonomy
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DataTaxonomy::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DataTaxonomy::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataTaxonomy::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DataTaxonomy::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DataTaxonomy::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataTaxonomy::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_attribute_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_attribute_count<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_class_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_class_count<T: Into<i32>>(self, v: T) -> Self