#[non_exhaustive]pub struct EncryptionConfig {
pub name: String,
pub key: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub encryption_state: EncryptionState,
pub etag: String,
pub failure_details: Option<FailureDetails>,
pub enable_metastore_encryption: bool,
/* private fields */
}Expand description
A Resource designed to manage encryption configurations for customers to support Customer Managed Encryption Keys (CMEK).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the EncryptionConfig. Format: organizations/{organization}/locations/{location}/encryptionConfigs/{encryption_config} Global location is not supported.
key: StringOptional. If a key is chosen, it means that the customer is using CMEK. If a key is not chosen, it means that the customer is using Google managed encryption.
create_time: Option<Timestamp>Output only. The time when the Encryption configuration was created.
update_time: Option<Timestamp>Output only. The time when the Encryption configuration was last updated.
encryption_state: EncryptionStateOutput only. The state of encryption of the databases.
etag: StringEtag of the EncryptionConfig. This is a strong etag.
failure_details: Option<FailureDetails>Output only. Details of the failure if anything related to Cmek db fails.
enable_metastore_encryption: boolOptional. Represent the state of CMEK opt-in for metastore.
Implementations
Sourceimpl EncryptionConfig
impl EncryptionConfig
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = EncryptionConfig::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = EncryptionConfig::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = EncryptionConfig::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = EncryptionConfig::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = EncryptionConfig::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = EncryptionConfig::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_encryption_state<T: Into<EncryptionState>>(self, v: T) -> Self
pub fn set_encryption_state<T: Into<EncryptionState>>(self, v: T) -> Self
Sets the value of encryption_state.
Example
use google_cloud_dataplex_v1::model::encryption_config::EncryptionState;
let x0 = EncryptionConfig::new().set_encryption_state(EncryptionState::Encrypting);
let x1 = EncryptionConfig::new().set_encryption_state(EncryptionState::Completed);
let x2 = EncryptionConfig::new().set_encryption_state(EncryptionState::Failed);Sourcepub fn set_failure_details<T>(self, v: T) -> Selfwhere
T: Into<FailureDetails>,
pub fn set_failure_details<T>(self, v: T) -> Selfwhere
T: Into<FailureDetails>,
Sets the value of failure_details.
Example
use google_cloud_dataplex_v1::model::encryption_config::FailureDetails;
let x = EncryptionConfig::new().set_failure_details(FailureDetails::default()/* use setters */);Sourcepub fn set_or_clear_failure_details<T>(self, v: Option<T>) -> Selfwhere
T: Into<FailureDetails>,
pub fn set_or_clear_failure_details<T>(self, v: Option<T>) -> Selfwhere
T: Into<FailureDetails>,
Sets or clears the value of failure_details.
Example
use google_cloud_dataplex_v1::model::encryption_config::FailureDetails;
let x = EncryptionConfig::new().set_or_clear_failure_details(Some(FailureDetails::default()/* use setters */));
let x = EncryptionConfig::new().set_or_clear_failure_details(None::<FailureDetails>);Sourcepub fn set_enable_metastore_encryption<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_metastore_encryption<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_metastore_encryption.
Example
let x = EncryptionConfig::new().set_enable_metastore_encryption(true);Trait Implementations
Sourceimpl Clone for EncryptionConfig
impl Clone for EncryptionConfig
Sourcefn clone(&self) -> EncryptionConfig
fn clone(&self) -> EncryptionConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EncryptionConfig
impl Debug for EncryptionConfig
Sourceimpl Default for EncryptionConfig
impl Default for EncryptionConfig
Sourcefn default() -> EncryptionConfig
fn default() -> EncryptionConfig
Sourceimpl Message for EncryptionConfig
impl Message for EncryptionConfig
Sourceimpl PartialEq for EncryptionConfig
impl PartialEq for EncryptionConfig
impl StructuralPartialEq for EncryptionConfig