#[non_exhaustive]pub struct Entity {Show 18 fields
pub name: String,
pub display_name: String,
pub description: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub id: String,
pub etag: String,
pub type: Type,
pub asset: String,
pub data_path: String,
pub data_path_pattern: String,
pub catalog_entry: String,
pub system: StorageSystem,
pub format: Option<StorageFormat>,
pub compatibility: Option<CompatibilityStatus>,
pub access: Option<StorageAccess>,
pub uid: String,
pub schema: Option<Schema>,
/* private fields */
}Expand description
Represents tables and fileset metadata contained within a zone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the entity, of the form:
projects/{project_number}/locations/{location_id}/lakes/{lake_id}/zones/{zone_id}/entities/{id}.
display_name: StringOptional. Display name must be shorter than or equal to 256 characters.
description: StringOptional. User friendly longer description text. Must be shorter than or equal to 1024 characters.
create_time: Option<Timestamp>Output only. The time when the entity was created.
update_time: Option<Timestamp>Output only. The time when the entity was last updated.
id: StringRequired. A user-provided entity ID. It is mutable, and will be used as the published table name. Specifying a new ID in an update entity request will override the existing value. The ID must contain only letters (a-z, A-Z), numbers (0-9), and underscores, and consist of 256 or fewer characters.
etag: StringOptional. The etag associated with the entity, which can be retrieved with a [GetEntity][] request. Required for update and delete requests.
type: TypeRequired. Immutable. The type of entity.
asset: StringRequired. Immutable. The ID of the asset associated with the storage location containing the entity data. The entity must be with in the same zone with the asset.
data_path: StringRequired. Immutable. The storage path of the entity data.
For Cloud Storage data, this is the fully-qualified path to the entity,
such as gs://bucket/path/to/data. For BigQuery data, this is the name of
the table resource, such as
projects/project_id/datasets/dataset_id/tables/table_id.
data_path_pattern: StringOptional. The set of items within the data path constituting the data in
the entity, represented as a glob path. Example:
gs://bucket/path/to/data/**/*.csv.
catalog_entry: StringOutput only. The name of the associated Data Catalog entry.
system: StorageSystemRequired. Immutable. Identifies the storage system of the entity data.
format: Option<StorageFormat>Required. Identifies the storage format of the entity data. It does not apply to entities with data stored in BigQuery.
compatibility: Option<CompatibilityStatus>Output only. Metadata stores that the entity is compatible with.
access: Option<StorageAccess>Output only. Identifies the access mechanism to the entity. Not user settable.
uid: StringOutput only. System generated unique ID for the Entity. This ID will be different if the Entity is deleted and re-created with the same name.
schema: Option<Schema>Required. The description of the data structure and layout.
The schema is not included in list responses. It is only included in
SCHEMA and FULL entity views of a GetEntity response.
Implementations
Sourceimpl Entity
impl Entity
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Entity::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Entity::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Entity::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Entity::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Entity::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Entity::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_data_path<T: Into<String>>(self, v: T) -> Self
pub fn set_data_path<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_data_path_pattern<T: Into<String>>(self, v: T) -> Self
pub fn set_data_path_pattern<T: Into<String>>(self, v: T) -> Self
Sets the value of data_path_pattern.
Example
let x = Entity::new().set_data_path_pattern("example");Sourcepub fn set_catalog_entry<T: Into<String>>(self, v: T) -> Self
pub fn set_catalog_entry<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_system<T: Into<StorageSystem>>(self, v: T) -> Self
pub fn set_system<T: Into<StorageSystem>>(self, v: T) -> Self
Sourcepub fn set_format<T>(self, v: T) -> Selfwhere
T: Into<StorageFormat>,
pub fn set_format<T>(self, v: T) -> Selfwhere
T: Into<StorageFormat>,
Sourcepub fn set_or_clear_format<T>(self, v: Option<T>) -> Selfwhere
T: Into<StorageFormat>,
pub fn set_or_clear_format<T>(self, v: Option<T>) -> Selfwhere
T: Into<StorageFormat>,
Sourcepub fn set_compatibility<T>(self, v: T) -> Selfwhere
T: Into<CompatibilityStatus>,
pub fn set_compatibility<T>(self, v: T) -> Selfwhere
T: Into<CompatibilityStatus>,
Sets the value of compatibility.
Example
use google_cloud_dataplex_v1::model::entity::CompatibilityStatus;
let x = Entity::new().set_compatibility(CompatibilityStatus::default()/* use setters */);Sourcepub fn set_or_clear_compatibility<T>(self, v: Option<T>) -> Selfwhere
T: Into<CompatibilityStatus>,
pub fn set_or_clear_compatibility<T>(self, v: Option<T>) -> Selfwhere
T: Into<CompatibilityStatus>,
Sets or clears the value of compatibility.
Example
use google_cloud_dataplex_v1::model::entity::CompatibilityStatus;
let x = Entity::new().set_or_clear_compatibility(Some(CompatibilityStatus::default()/* use setters */));
let x = Entity::new().set_or_clear_compatibility(None::<CompatibilityStatus>);Sourcepub fn set_access<T>(self, v: T) -> Selfwhere
T: Into<StorageAccess>,
pub fn set_access<T>(self, v: T) -> Selfwhere
T: Into<StorageAccess>,
Sourcepub fn set_or_clear_access<T>(self, v: Option<T>) -> Selfwhere
T: Into<StorageAccess>,
pub fn set_or_clear_access<T>(self, v: Option<T>) -> Selfwhere
T: Into<StorageAccess>,
Sourcepub fn set_schema<T>(self, v: T) -> Self
pub fn set_schema<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_schema<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_schema<T>(self, v: Option<T>) -> Self