#[non_exhaustive]pub struct Entry {
pub name: String,
pub entry_type: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub aspects: HashMap<String, Aspect>,
pub parent_entry: String,
pub fully_qualified_name: String,
pub entry_source: Option<EntrySource>,
/* private fields */
}Expand description
An entry is a representation of a data resource that can be described by various metadata.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The relative resource name of the entry, in the format
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}.
entry_type: StringRequired. Immutable. The relative resource name of the entry type that was
used to create this entry, in the format
projects/{project_id_or_number}/locations/{location_id}/entryTypes/{entry_type_id}.
create_time: Option<Timestamp>Output only. The time when the entry was created in Dataplex Universal Catalog.
update_time: Option<Timestamp>Output only. The time when the entry was last updated in Dataplex Universal Catalog.
aspects: HashMap<String, Aspect>Optional. The aspects that are attached to the entry. Depending on how the aspect is attached to the entry, the format of the aspect key can be one of the following:
- If the aspect is attached directly to the entry:
{project_id_or_number}.{location_id}.{aspect_type_id} - If the aspect is attached to an entry’s path:
{project_id_or_number}.{location_id}.{aspect_type_id}@{path}
parent_entry: StringOptional. Immutable. The resource name of the parent entry, in the format
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}.
fully_qualified_name: StringOptional. A name for the entry that can be referenced by an external system. For more information, see Fully qualified names. The maximum size of the field is 4000 characters.
entry_source: Option<EntrySource>Optional. Information related to the source system of the data resource that is represented by the entry.
Implementations
Sourceimpl Entry
impl Entry
Sourcepub fn set_entry_type<T: Into<String>>(self, v: T) -> Self
pub fn set_entry_type<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Entry::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Entry::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Entry::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Entry::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Entry::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Entry::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_aspects<T, K, V>(self, v: T) -> Self
pub fn set_aspects<T, K, V>(self, v: T) -> Self
Sourcepub fn set_parent_entry<T: Into<String>>(self, v: T) -> Self
pub fn set_parent_entry<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_fully_qualified_name<T: Into<String>>(self, v: T) -> Self
pub fn set_fully_qualified_name<T: Into<String>>(self, v: T) -> Self
Sets the value of fully_qualified_name.
Example
let x = Entry::new().set_fully_qualified_name("example");Sourcepub fn set_entry_source<T>(self, v: T) -> Selfwhere
T: Into<EntrySource>,
pub fn set_entry_source<T>(self, v: T) -> Selfwhere
T: Into<EntrySource>,
Sets the value of entry_source.
Example
use google_cloud_dataplex_v1::model::EntrySource;
let x = Entry::new().set_entry_source(EntrySource::default()/* use setters */);Sourcepub fn set_or_clear_entry_source<T>(self, v: Option<T>) -> Selfwhere
T: Into<EntrySource>,
pub fn set_or_clear_entry_source<T>(self, v: Option<T>) -> Selfwhere
T: Into<EntrySource>,
Sets or clears the value of entry_source.
Example
use google_cloud_dataplex_v1::model::EntrySource;
let x = Entry::new().set_or_clear_entry_source(Some(EntrySource::default()/* use setters */));
let x = Entry::new().set_or_clear_entry_source(None::<EntrySource>);Trait Implementations
impl StructuralPartialEq for Entry