#[non_exhaustive]pub struct EntryGroup {
pub name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub display_name: String,
pub labels: HashMap<String, String>,
pub etag: String,
pub transfer_status: TransferStatus,
/* private fields */
}Expand description
An Entry Group represents a logical grouping of one or more Entries.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The relative resource name of the EntryGroup, in the format projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}.
uid: StringOutput only. System generated globally unique ID for the EntryGroup. If you delete and recreate the EntryGroup with the same name, this ID will be different.
create_time: Option<Timestamp>Output only. The time when the EntryGroup was created.
update_time: Option<Timestamp>Output only. The time when the EntryGroup was last updated.
description: StringOptional. Description of the EntryGroup.
display_name: StringOptional. User friendly display name.
labels: HashMap<String, String>Optional. User-defined labels for the EntryGroup.
etag: StringThis checksum is computed by the service, and might be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
transfer_status: TransferStatusOutput only. Denotes the transfer status of the Entry Group. It is unspecified for Entry Group created from Dataplex API.
Implementations
Sourceimpl EntryGroup
impl EntryGroup
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = EntryGroup::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = EntryGroup::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = EntryGroup::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = EntryGroup::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = EntryGroup::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = EntryGroup::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_transfer_status<T: Into<TransferStatus>>(self, v: T) -> Self
pub fn set_transfer_status<T: Into<TransferStatus>>(self, v: T) -> Self
Sets the value of transfer_status.
Example
use google_cloud_dataplex_v1::model::TransferStatus;
let x0 = EntryGroup::new().set_transfer_status(TransferStatus::Migrated);
let x1 = EntryGroup::new().set_transfer_status(TransferStatus::Transferred);Trait Implementations
Sourceimpl Clone for EntryGroup
impl Clone for EntryGroup
Sourcefn clone(&self) -> EntryGroup
fn clone(&self) -> EntryGroup
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EntryGroup
impl Debug for EntryGroup
Sourceimpl Default for EntryGroup
impl Default for EntryGroup
Sourcefn default() -> EntryGroup
fn default() -> EntryGroup
Sourceimpl PartialEq for EntryGroup
impl PartialEq for EntryGroup
impl StructuralPartialEq for EntryGroup