#[non_exhaustive]pub struct EntryType {Show 13 fields
pub name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub description: String,
pub display_name: String,
pub labels: HashMap<String, String>,
pub etag: String,
pub type_aliases: Vec<String>,
pub platform: String,
pub system: String,
pub required_aspects: Vec<AspectInfo>,
pub authorization: Option<Authorization>,
/* private fields */
}Expand description
Entry Type is a template for creating Entries.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The relative resource name of the EntryType, of the form: projects/{project_number}/locations/{location_id}/entryTypes/{entry_type_id}.
uid: StringOutput only. System generated globally unique ID for the EntryType. This ID will be different if the EntryType is deleted and re-created with the same name.
create_time: Option<Timestamp>Output only. The time when the EntryType was created.
update_time: Option<Timestamp>Output only. The time when the EntryType was last updated.
description: StringOptional. Description of the EntryType.
display_name: StringOptional. User friendly display name.
labels: HashMap<String, String>Optional. User-defined labels for the EntryType.
etag: StringOptional. This checksum is computed by the service, and might be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
type_aliases: Vec<String>Optional. Indicates the classes this Entry Type belongs to, for example, TABLE, DATABASE, MODEL.
platform: StringOptional. The platform that Entries of this type belongs to.
system: StringOptional. The system that Entries of this type belongs to. Examples include CloudSQL, MariaDB etc
required_aspects: Vec<AspectInfo>AspectInfo for the entry type.
Immutable. Authorization defined for this type.
Implementations
Sourceimpl EntryType
impl EntryType
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = EntryType::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = EntryType::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = EntryType::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = EntryType::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = EntryType::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = EntryType::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_type_aliases<T, V>(self, v: T) -> Self
pub fn set_type_aliases<T, V>(self, v: T) -> Self
Sets the value of type_aliases.
Example
let x = EntryType::new().set_type_aliases(["a", "b", "c"]);Sourcepub fn set_platform<T: Into<String>>(self, v: T) -> Self
pub fn set_platform<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_system<T: Into<String>>(self, v: T) -> Self
pub fn set_system<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_required_aspects<T, V>(self, v: T) -> Self
pub fn set_required_aspects<T, V>(self, v: T) -> Self
Sets the value of required_aspects.
Example
use google_cloud_dataplex_v1::model::entry_type::AspectInfo;
let x = EntryType::new()
.set_required_aspects([
AspectInfo::default()/* use setters */,
AspectInfo::default()/* use (different) setters */,
]);Sets the value of authorization.
Example
use google_cloud_dataplex_v1::model::entry_type::Authorization;
let x = EntryType::new().set_authorization(Authorization::default()/* use setters */);Sets or clears the value of authorization.
Example
use google_cloud_dataplex_v1::model::entry_type::Authorization;
let x = EntryType::new().set_or_clear_authorization(Some(Authorization::default()/* use setters */));
let x = EntryType::new().set_or_clear_authorization(None::<Authorization>);