#[non_exhaustive]pub struct GenerateDataQualityRulesResponse {
pub rule: Vec<DataQualityRule>,
/* private fields */
}Expand description
Response details for data quality rule recommendations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule: Vec<DataQualityRule>The data quality rules that Dataplex Universal Catalog generates based on the results of a data profiling scan.
Implementations
Sourceimpl GenerateDataQualityRulesResponse
impl GenerateDataQualityRulesResponse