#[non_exhaustive]pub struct Job {
pub name: String,
pub uid: String,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub state: State,
pub retry_count: u32,
pub service: Service,
pub service_job: String,
pub message: String,
pub labels: HashMap<String, String>,
pub trigger: Trigger,
pub execution_spec: Option<ExecutionSpec>,
/* private fields */
}Expand description
A job represents an instance of a task.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The relative resource name of the job, of the form:
projects/{project_number}/locations/{location_id}/lakes/{lake_id}/tasks/{task_id}/jobs/{job_id}.
uid: StringOutput only. System generated globally unique ID for the job.
start_time: Option<Timestamp>Output only. The time when the job was started.
end_time: Option<Timestamp>Output only. The time when the job ended.
state: StateOutput only. Execution state for the job.
retry_count: u32Output only. The number of times the job has been retried (excluding the initial attempt).
service: ServiceOutput only. The underlying service running a job.
service_job: StringOutput only. The full resource name for the job run under a particular service.
message: StringOutput only. Additional information about the current state.
labels: HashMap<String, String>Output only. User-defined labels for the task.
trigger: TriggerOutput only. Job execution trigger.
execution_spec: Option<ExecutionSpec>Output only. Spec related to how a task is executed.
Implementations
Sourceimpl Job
impl Job
Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = Job::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = Job::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = Job::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_retry_count<T: Into<u32>>(self, v: T) -> Self
pub fn set_retry_count<T: Into<u32>>(self, v: T) -> Self
Sourcepub fn set_service<T: Into<Service>>(self, v: T) -> Self
pub fn set_service<T: Into<Service>>(self, v: T) -> Self
Sourcepub fn set_service_job<T: Into<String>>(self, v: T) -> Self
pub fn set_service_job<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_message<T: Into<String>>(self, v: T) -> Self
pub fn set_message<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_trigger<T: Into<Trigger>>(self, v: T) -> Self
pub fn set_trigger<T: Into<Trigger>>(self, v: T) -> Self
Sourcepub fn set_execution_spec<T>(self, v: T) -> Selfwhere
T: Into<ExecutionSpec>,
pub fn set_execution_spec<T>(self, v: T) -> Selfwhere
T: Into<ExecutionSpec>,
Sets the value of execution_spec.
Example
use google_cloud_dataplex_v1::model::task::ExecutionSpec;
let x = Job::new().set_execution_spec(ExecutionSpec::default()/* use setters */);Sourcepub fn set_or_clear_execution_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExecutionSpec>,
pub fn set_or_clear_execution_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<ExecutionSpec>,
Sets or clears the value of execution_spec.
Example
use google_cloud_dataplex_v1::model::task::ExecutionSpec;
let x = Job::new().set_or_clear_execution_spec(Some(ExecutionSpec::default()/* use setters */));
let x = Job::new().set_or_clear_execution_spec(None::<ExecutionSpec>);Trait Implementations
impl StructuralPartialEq for Job