ListMetadataFeedsRequest

Struct ListMetadataFeedsRequest 

#[non_exhaustive]
pub struct ListMetadataFeedsRequest { pub parent: String, pub page_size: i32, pub page_token: String, pub filter: String, pub order_by: String, /* private fields */ }
Request message for ListMetadataFeedsRequest.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The resource name of the parent location, in the format projects/{project_id_or_number}/locations/{location_id}

page_size: i32

Optional. The maximum number of metadata feeds to return. The service might return fewer feeds than this value. If unspecified, at most 10 feeds are returned. The maximum value is 1,000.

page_token: String

Optional. The page token received from a previous ListMetadataFeeds call. Provide this token to retrieve the subsequent page of results. When paginating, all other parameters that are provided to the ListMetadataFeeds request must match the call that provided the page token.

filter: String

Optional. Filter request. Filters are case-sensitive. The service supports the following formats:

  • labels.key1 = "value1"
  • labels:key1
  • name = "value"

You can combine filters with AND, OR, and NOT operators.

order_by: String

Optional. The field to sort the results by, either name or create_time. If not specified, the ordering is undefined.

Implementations

Source

impl ListMetadataFeedsRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = ListMetadataFeedsRequest::new().set_parent("example");
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = ListMetadataFeedsRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = ListMetadataFeedsRequest::new().set_page_token("example");
pub fn set_filter<T: Into<String>>(self, v: T) -> Self

Sets the value of filter.

Example
let x = ListMetadataFeedsRequest::new().set_filter("example");
pub fn set_order_by<T: Into<String>>(self, v: T) -> Self

Sets the value of order_by.

Example
let x = ListMetadataFeedsRequest::new().set_order_by("example");