LookupEntryLinksRequest

Struct LookupEntryLinksRequest 

#[non_exhaustive]
pub struct LookupEntryLinksRequest { pub name: String, pub entry: String, pub entry_mode: EntryMode, pub entry_link_types: Vec<String>, pub page_size: i32, pub page_token: String, /* private fields */ }
Request message for LookupEntryLinks.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The project to which the request should be attributed to Format: projects/{project_id_or_number}/locations/{location_id}.

entry: String

Required. The resource name of the referred Entry. Format: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}. Entry Links which references this entry will be returned in the response.

entry_mode: EntryMode

Mode of entry reference.

entry_link_types: Vec<String>

Entry link types to filter the response by. If empty, all entry link types will be returned. At most 10 entry link types can be specified.

page_size: i32

Maximum number of EntryLinks to return. The service may return fewer than this value. If unspecified, at most 10 EntryLinks will be returned. The maximum value is 10; values above 10 will be coerced to 10.

page_token: String

Page token received from a previous LookupEntryLinks call. Provide this to retrieve the subsequent page. When paginating, all other parameters that are provided to the LookupEntryLinks request must match the call that provided the page token.

Implementations

Source

impl LookupEntryLinksRequest

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = LookupEntryLinksRequest::new().set_name("example");
pub fn set_entry<T: Into<String>>(self, v: T) -> Self

Sets the value of entry.

Example
let x = LookupEntryLinksRequest::new().set_entry("example");
pub fn set_entry_mode<T: Into<EntryMode>>(self, v: T) -> Self

Sets the value of entry_mode.

Example
use google_cloud_dataplex_v1::model::lookup_entry_links_request::EntryMode;
let x0 = LookupEntryLinksRequest::new().set_entry_mode(EntryMode::Source);
let x1 = LookupEntryLinksRequest::new().set_entry_mode(EntryMode::Target);
pub fn set_entry_link_types<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of entry_link_types.

Example
let x = LookupEntryLinksRequest::new().set_entry_link_types(["a", "b", "c"]);
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self

Sets the value of page_size.

Example
let x = LookupEntryLinksRequest::new().set_page_size(42);
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self

Sets the value of page_token.

Example
let x = LookupEntryLinksRequest::new().set_page_token("example");