#[non_exhaustive]pub struct LookupEntryLinksResponse {
pub entry_links: Vec<EntryLink>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for LookupEntryLinks.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entry_links: Vec<EntryLink>List of entry links that reference the specified entry.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more results in the list.
Implementations
Sourceimpl LookupEntryLinksResponse
impl LookupEntryLinksResponse
pub fn new() -> Self
Sourcepub fn set_entry_links<T, V>(self, v: T) -> Self
pub fn set_entry_links<T, V>(self, v: T) -> Self
Sets the value of entry_links.
Example
ⓘ
use google_cloud_dataplex_v1::model::EntryLink;
let x = LookupEntryLinksResponse::new()
.set_entry_links([
EntryLink::default()/* use setters */,
EntryLink::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = LookupEntryLinksResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for LookupEntryLinksResponse
impl Clone for LookupEntryLinksResponse
Sourcefn clone(&self) -> LookupEntryLinksResponse
fn clone(&self) -> LookupEntryLinksResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LookupEntryLinksResponse
impl Debug for LookupEntryLinksResponse
Sourceimpl Default for LookupEntryLinksResponse
impl Default for LookupEntryLinksResponse
Sourcefn default() -> LookupEntryLinksResponse
fn default() -> LookupEntryLinksResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for LookupEntryLinksResponse
impl Message for LookupEntryLinksResponse
Sourceimpl PartialEq for LookupEntryLinksResponse
impl PartialEq for LookupEntryLinksResponse
impl StructuralPartialEq for LookupEntryLinksResponse