#[non_exhaustive]pub struct MetadataJob {
pub name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub type: Type,
pub status: Option<Status>,
pub spec: Option<Spec>,
pub result: Option<Result>,
/* private fields */
}Expand description
A metadata job resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. The name of the resource that the configuration is
applied to, in the format
projects/{project_number}/locations/{location_id}/metadataJobs/{metadata_job_id}.
uid: StringOutput only. A system-generated, globally unique ID for the metadata job. If the metadata job is deleted and then re-created with the same name, this ID is different.
create_time: Option<Timestamp>Output only. The time when the metadata job was created.
update_time: Option<Timestamp>Output only. The time when the metadata job was updated.
labels: HashMap<String, String>Optional. User-defined labels.
type: TypeRequired. Metadata job type.
status: Option<Status>Output only. Metadata job status.
spec: Option<Spec>result: Option<Result>Implementations
Sourceimpl MetadataJob
impl MetadataJob
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = MetadataJob::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = MetadataJob::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = MetadataJob::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = MetadataJob::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = MetadataJob::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = MetadataJob::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_status<T>(self, v: T) -> Self
pub fn set_status<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_status<T>(self, v: Option<T>) -> Self
Sourcepub fn set_spec<T: Into<Option<Spec>>>(self, v: T) -> Self
pub fn set_spec<T: Into<Option<Spec>>>(self, v: T) -> Self
Sets the value of spec.
Note that all the setters affecting spec are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::metadata_job::ImportJobSpec;
let x = MetadataJob::new().set_spec(Some(
google_cloud_dataplex_v1::model::metadata_job::Spec::ImportSpec(ImportJobSpec::default().into())));Sourcepub fn import_spec(&self) -> Option<&Box<ImportJobSpec>>
pub fn import_spec(&self) -> Option<&Box<ImportJobSpec>>
The value of spec
if it holds a ImportSpec, None if the field is not set or
holds a different branch.
Sourcepub fn set_import_spec<T: Into<Box<ImportJobSpec>>>(self, v: T) -> Self
pub fn set_import_spec<T: Into<Box<ImportJobSpec>>>(self, v: T) -> Self
Sets the value of spec
to hold a ImportSpec.
Note that all the setters affecting spec are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::metadata_job::ImportJobSpec;
let x = MetadataJob::new().set_import_spec(ImportJobSpec::default()/* use setters */);
assert!(x.import_spec().is_some());
assert!(x.export_spec().is_none());Sourcepub fn export_spec(&self) -> Option<&Box<ExportJobSpec>>
pub fn export_spec(&self) -> Option<&Box<ExportJobSpec>>
The value of spec
if it holds a ExportSpec, None if the field is not set or
holds a different branch.
Sourcepub fn set_export_spec<T: Into<Box<ExportJobSpec>>>(self, v: T) -> Self
pub fn set_export_spec<T: Into<Box<ExportJobSpec>>>(self, v: T) -> Self
Sets the value of spec
to hold a ExportSpec.
Note that all the setters affecting spec are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::metadata_job::ExportJobSpec;
let x = MetadataJob::new().set_export_spec(ExportJobSpec::default()/* use setters */);
assert!(x.export_spec().is_some());
assert!(x.import_spec().is_none());Sourcepub fn set_result<T: Into<Option<Result>>>(self, v: T) -> Self
pub fn set_result<T: Into<Option<Result>>>(self, v: T) -> Self
Sets the value of result.
Note that all the setters affecting result are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::metadata_job::ImportJobResult;
let x = MetadataJob::new().set_result(Some(
google_cloud_dataplex_v1::model::metadata_job::Result::ImportResult(ImportJobResult::default().into())));Sourcepub fn import_result(&self) -> Option<&Box<ImportJobResult>>
pub fn import_result(&self) -> Option<&Box<ImportJobResult>>
The value of result
if it holds a ImportResult, None if the field is not set or
holds a different branch.
Sourcepub fn set_import_result<T: Into<Box<ImportJobResult>>>(self, v: T) -> Self
pub fn set_import_result<T: Into<Box<ImportJobResult>>>(self, v: T) -> Self
Sets the value of result
to hold a ImportResult.
Note that all the setters affecting result are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::metadata_job::ImportJobResult;
let x = MetadataJob::new().set_import_result(ImportJobResult::default()/* use setters */);
assert!(x.import_result().is_some());
assert!(x.export_result().is_none());Sourcepub fn export_result(&self) -> Option<&Box<ExportJobResult>>
pub fn export_result(&self) -> Option<&Box<ExportJobResult>>
The value of result
if it holds a ExportResult, None if the field is not set or
holds a different branch.
Sourcepub fn set_export_result<T: Into<Box<ExportJobResult>>>(self, v: T) -> Self
pub fn set_export_result<T: Into<Box<ExportJobResult>>>(self, v: T) -> Self
Sets the value of result
to hold a ExportResult.
Note that all the setters affecting result are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::metadata_job::ExportJobResult;
let x = MetadataJob::new().set_export_result(ExportJobResult::default()/* use setters */);
assert!(x.export_result().is_some());
assert!(x.import_result().is_none());Trait Implementations
Sourceimpl Clone for MetadataJob
impl Clone for MetadataJob
Sourcefn clone(&self) -> MetadataJob
fn clone(&self) -> MetadataJob
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MetadataJob
impl Debug for MetadataJob
Sourceimpl Default for MetadataJob
impl Default for MetadataJob
Sourcefn default() -> MetadataJob
fn default() -> MetadataJob
Sourceimpl Message for MetadataJob
impl Message for MetadataJob
Sourceimpl PartialEq for MetadataJob
impl PartialEq for MetadataJob
impl StructuralPartialEq for MetadataJob