#[non_exhaustive]pub struct Schema {
pub user_managed: bool,
pub fields: Vec<SchemaField>,
pub partition_fields: Vec<PartitionField>,
pub partition_style: PartitionStyle,
/* private fields */
}Expand description
Schema information describing the structure and layout of the data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_managed: boolRequired. Set to true if user-managed or false if managed by Dataplex
Universal Catalog. The default is false (managed by Dataplex Universal
Catalog).
-
Set to
falseto enable Dataplex Universal Catalog discovery to update the schema. including new data discovery, schema inference, and schema evolution. Users retain the ability to input and edit the schema. Dataplex Universal Catalog treats schema input by the user as though produced by a previous Dataplex Universal Catalog discovery operation, and it will evolve the schema and take action based on that treatment. -
Set to
trueto fully manage the entity schema. This setting guarantees that Dataplex Universal Catalog will not change schema fields.
fields: Vec<SchemaField>Optional. The sequence of fields describing data in table entities. Note: BigQuery SchemaFields are immutable.
partition_fields: Vec<PartitionField>Optional. The sequence of fields describing the partition structure in entities. If this field is empty, there are no partitions within the data.
partition_style: PartitionStyleOptional. The structure of paths containing partition data within the entity.
Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn set_user_managed<T: Into<bool>>(self, v: T) -> Self
pub fn set_user_managed<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_fields<T, V>(self, v: T) -> Self
pub fn set_fields<T, V>(self, v: T) -> Self
Sourcepub fn set_partition_fields<T, V>(self, v: T) -> Self
pub fn set_partition_fields<T, V>(self, v: T) -> Self
Sets the value of partition_fields.
Example
use google_cloud_dataplex_v1::model::schema::PartitionField;
let x = Schema::new()
.set_partition_fields([
PartitionField::default()/* use setters */,
PartitionField::default()/* use (different) setters */,
]);Sourcepub fn set_partition_style<T: Into<PartitionStyle>>(self, v: T) -> Self
pub fn set_partition_style<T: Into<PartitionStyle>>(self, v: T) -> Self
Sets the value of partition_style.
Example
use google_cloud_dataplex_v1::model::schema::PartitionStyle;
let x0 = Schema::new().set_partition_style(PartitionStyle::HiveCompatible);Trait Implementations
impl StructuralPartialEq for Schema