#[non_exhaustive]pub struct StorageFormat {
pub format: Format,
pub compression_format: CompressionFormat,
pub mime_type: String,
pub options: Option<Options>,
/* private fields */
}Expand description
Describes the format of the data within its storage location.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.format: FormatOutput only. The data format associated with the stored data, which represents content type values. The value is inferred from mime type.
compression_format: CompressionFormatOptional. The compression type associated with the stored data. If unspecified, the data is uncompressed.
mime_type: StringRequired. The mime type descriptor for the data. Must match the pattern {type}/{subtype}. Supported values:
- application/x-parquet
- application/x-avro
- application/x-orc
- application/x-tfrecord
- application/x-parquet+iceberg
- application/x-avro+iceberg
- application/x-orc+iceberg
- application/json
- application/{subtypes}
- text/csv
- text/<subtypes>
- image/{image subtype}
- video/{video subtype}
- audio/{audio subtype}
options: Option<Options>Additional format-specific options.
Implementations
Sourceimpl StorageFormat
impl StorageFormat
Sourcepub fn set_format<T: Into<Format>>(self, v: T) -> Self
pub fn set_format<T: Into<Format>>(self, v: T) -> Self
Sourcepub fn set_compression_format<T: Into<CompressionFormat>>(self, v: T) -> Self
pub fn set_compression_format<T: Into<CompressionFormat>>(self, v: T) -> Self
Sets the value of compression_format.
Example
use google_cloud_dataplex_v1::model::storage_format::CompressionFormat;
let x0 = StorageFormat::new().set_compression_format(CompressionFormat::Gzip);
let x1 = StorageFormat::new().set_compression_format(CompressionFormat::Bzip2);Sourcepub fn set_mime_type<T: Into<String>>(self, v: T) -> Self
pub fn set_mime_type<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_options<T: Into<Option<Options>>>(self, v: T) -> Self
pub fn set_options<T: Into<Option<Options>>>(self, v: T) -> Self
Sets the value of options.
Note that all the setters affecting options are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::storage_format::CsvOptions;
let x = StorageFormat::new().set_options(Some(
google_cloud_dataplex_v1::model::storage_format::Options::Csv(CsvOptions::default().into())));Sourcepub fn csv(&self) -> Option<&Box<CsvOptions>>
pub fn csv(&self) -> Option<&Box<CsvOptions>>
The value of options
if it holds a Csv, None if the field is not set or
holds a different branch.
Sourcepub fn set_csv<T: Into<Box<CsvOptions>>>(self, v: T) -> Self
pub fn set_csv<T: Into<Box<CsvOptions>>>(self, v: T) -> Self
Sets the value of options
to hold a Csv.
Note that all the setters affecting options are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::storage_format::CsvOptions;
let x = StorageFormat::new().set_csv(CsvOptions::default()/* use setters */);
assert!(x.csv().is_some());
assert!(x.json().is_none());
assert!(x.iceberg().is_none());Sourcepub fn json(&self) -> Option<&Box<JsonOptions>>
pub fn json(&self) -> Option<&Box<JsonOptions>>
The value of options
if it holds a Json, None if the field is not set or
holds a different branch.
Sourcepub fn set_json<T: Into<Box<JsonOptions>>>(self, v: T) -> Self
pub fn set_json<T: Into<Box<JsonOptions>>>(self, v: T) -> Self
Sets the value of options
to hold a Json.
Note that all the setters affecting options are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::storage_format::JsonOptions;
let x = StorageFormat::new().set_json(JsonOptions::default()/* use setters */);
assert!(x.json().is_some());
assert!(x.csv().is_none());
assert!(x.iceberg().is_none());Sourcepub fn iceberg(&self) -> Option<&Box<IcebergOptions>>
pub fn iceberg(&self) -> Option<&Box<IcebergOptions>>
The value of options
if it holds a Iceberg, None if the field is not set or
holds a different branch.
Sourcepub fn set_iceberg<T: Into<Box<IcebergOptions>>>(self, v: T) -> Self
pub fn set_iceberg<T: Into<Box<IcebergOptions>>>(self, v: T) -> Self
Sets the value of options
to hold a Iceberg.
Note that all the setters affecting options are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::storage_format::IcebergOptions;
let x = StorageFormat::new().set_iceberg(IcebergOptions::default()/* use setters */);
assert!(x.iceberg().is_some());
assert!(x.csv().is_none());
assert!(x.json().is_none());Trait Implementations
Sourceimpl Clone for StorageFormat
impl Clone for StorageFormat
Sourcefn clone(&self) -> StorageFormat
fn clone(&self) -> StorageFormat
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for StorageFormat
impl Debug for StorageFormat
Sourceimpl Default for StorageFormat
impl Default for StorageFormat
Sourcefn default() -> StorageFormat
fn default() -> StorageFormat
Sourceimpl Message for StorageFormat
impl Message for StorageFormat
Sourceimpl PartialEq for StorageFormat
impl PartialEq for StorageFormat
impl StructuralPartialEq for StorageFormat