Zone

Struct Zone 

#[non_exhaustive]
pub struct Zone { pub name: String, pub display_name: String, pub uid: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub description: String, pub state: State, pub type: Type, pub discovery_spec: Option<DiscoverySpec>, pub resource_spec: Option<ResourceSpec>, pub asset_status: Option<AssetStatus>, /* private fields */ }
A zone represents a logical group of related assets within a lake. A zone can be used to map to organizational structure or represent stages of data readiness from raw to curated. It provides managing behavior that is shared or inherited by all contained assets.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. The relative resource name of the zone, of the form: projects/{project_number}/locations/{location_id}/lakes/{lake_id}/zones/{zone_id}.

display_name: String

Optional. User friendly display name.

uid: String

Output only. System generated globally unique ID for the zone. This ID will be different if the zone is deleted and re-created with the same name.

create_time: Option<Timestamp>

Output only. The time when the zone was created.

update_time: Option<Timestamp>

Output only. The time when the zone was last updated.

labels: HashMap<String, String>

Optional. User defined labels for the zone.

description: String

Optional. Description of the zone.

state: State

Output only. Current state of the zone.

type: Type

Required. Immutable. The type of the zone.

discovery_spec: Option<DiscoverySpec>

Optional. Specification of the discovery feature applied to data in this zone.

resource_spec: Option<ResourceSpec>

Required. Specification of the resources that are referenced by the assets within this zone.

asset_status: Option<AssetStatus>

Output only. Aggregated status of the underlying assets of the zone.

Implementations

Source

impl Zone

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Zone::new().set_name("example");
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = Zone::new().set_display_name("example");
pub fn set_uid<T: Into<String>>(self, v: T) -> Self

Sets the value of uid.

Example
let x = Zone::new().set_uid("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Zone::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Zone::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Zone::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = Zone::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = Zone::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Zone::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Zone::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = Zone::new().set_description("example");
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_dataplex_v1::model::State;
let x0 = Zone::new().set_state(State::Active);
let x1 = Zone::new().set_state(State::Creating);
let x2 = Zone::new().set_state(State::Deleting);
pub fn set_type<T: Into<Type>>(self, v: T) -> Self

Sets the value of r#type.

Example
use google_cloud_dataplex_v1::model::zone::Type;
let x0 = Zone::new().set_type(Type::Raw);
let x1 = Zone::new().set_type(Type::Curated);
pub fn set_discovery_spec<T>(self, v: T) -> Self
where T: Into<DiscoverySpec>,

Sets the value of discovery_spec.

Example
use google_cloud_dataplex_v1::model::zone::DiscoverySpec;
let x = Zone::new().set_discovery_spec(DiscoverySpec::default()/* use setters */);
pub fn set_or_clear_discovery_spec<T>(self, v: Option<T>) -> Self
where T: Into<DiscoverySpec>,

Sets or clears the value of discovery_spec.

Example
use google_cloud_dataplex_v1::model::zone::DiscoverySpec;
let x = Zone::new().set_or_clear_discovery_spec(Some(DiscoverySpec::default()/* use setters */));
let x = Zone::new().set_or_clear_discovery_spec(None::<DiscoverySpec>);
pub fn set_resource_spec<T>(self, v: T) -> Self
where T: Into<ResourceSpec>,

Sets the value of resource_spec.

Example
use google_cloud_dataplex_v1::model::zone::ResourceSpec;
let x = Zone::new().set_resource_spec(ResourceSpec::default()/* use setters */);
pub fn set_or_clear_resource_spec<T>(self, v: Option<T>) -> Self
where T: Into<ResourceSpec>,

Sets or clears the value of resource_spec.

Example
use google_cloud_dataplex_v1::model::zone::ResourceSpec;
let x = Zone::new().set_or_clear_resource_spec(Some(ResourceSpec::default()/* use setters */));
let x = Zone::new().set_or_clear_resource_spec(None::<ResourceSpec>);
pub fn set_asset_status<T>(self, v: T) -> Self
where T: Into<AssetStatus>,

Sets the value of asset_status.

Example
use google_cloud_dataplex_v1::model::AssetStatus;
let x = Zone::new().set_asset_status(AssetStatus::default()/* use setters */);
pub fn set_or_clear_asset_status<T>(self, v: Option<T>) -> Self
where T: Into<AssetStatus>,

Sets or clears the value of asset_status.

Example
use google_cloud_dataplex_v1::model::AssetStatus;
let x = Zone::new().set_or_clear_asset_status(Some(AssetStatus::default()/* use setters */));
let x = Zone::new().set_or_clear_asset_status(None::<AssetStatus>);