#[non_exhaustive]pub struct ExecutionSpec {
pub args: HashMap<String, String>,
pub service_account: String,
pub project: String,
pub max_job_execution_lifetime: Option<Duration>,
pub kms_key: String,
/* private fields */
}Expand description
Execution related settings, like retry and service_account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.args: HashMap<String, String>Optional. The arguments to pass to the task. The args can use placeholders of the format ${placeholder} as part of key/value string. These will be interpolated before passing the args to the driver. Currently supported placeholders:
- ${task_id}
- ${job_time} To pass positional args, set the key as TASK_ARGS. The value should be a comma-separated string of all the positional arguments. To use a delimiter other than comma, refer to https://cloud.google.com/sdk/gcloud/reference/topic/escaping. In case of other keys being present in the args, then TASK_ARGS will be passed as the last argument.
service_account: StringRequired. Service account to use to execute a task. If not provided, the default Compute service account for the project is used.
project: StringOptional. The project in which jobs are run. By default, the project containing the Lake is used. If a project is provided, the ExecutionSpec.service_account must belong to this project.
max_job_execution_lifetime: Option<Duration>Optional. The maximum duration after which the job execution is expired.
kms_key: StringOptional. The Cloud KMS key to use for encryption, of the form:
projects/{project_number}/locations/{location_id}/keyRings/{key-ring-name}/cryptoKeys/{key-name}.
Implementations
Sourceimpl ExecutionSpec
impl ExecutionSpec
Sourcepub fn set_service_account<T: Into<String>>(self, v: T) -> Self
pub fn set_service_account<T: Into<String>>(self, v: T) -> Self
Sets the value of service_account.
Example
let x = ExecutionSpec::new().set_service_account("example");Sourcepub fn set_project<T: Into<String>>(self, v: T) -> Self
pub fn set_project<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_max_job_execution_lifetime<T>(self, v: T) -> Self
pub fn set_max_job_execution_lifetime<T>(self, v: T) -> Self
Sets the value of max_job_execution_lifetime.
Example
use wkt::Duration;
let x = ExecutionSpec::new().set_max_job_execution_lifetime(Duration::default()/* use setters */);Sourcepub fn set_or_clear_max_job_execution_lifetime<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_max_job_execution_lifetime<T>(self, v: Option<T>) -> Self
Sets or clears the value of max_job_execution_lifetime.
Example
use wkt::Duration;
let x = ExecutionSpec::new().set_or_clear_max_job_execution_lifetime(Some(Duration::default()/* use setters */));
let x = ExecutionSpec::new().set_or_clear_max_job_execution_lifetime(None::<Duration>);Trait Implementations
Sourceimpl Clone for ExecutionSpec
impl Clone for ExecutionSpec
Sourcefn clone(&self) -> ExecutionSpec
fn clone(&self) -> ExecutionSpec
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExecutionSpec
impl Debug for ExecutionSpec
Sourceimpl Default for ExecutionSpec
impl Default for ExecutionSpec
Sourcefn default() -> ExecutionSpec
fn default() -> ExecutionSpec
Sourceimpl Message for ExecutionSpec
impl Message for ExecutionSpec
Sourceimpl PartialEq for ExecutionSpec
impl PartialEq for ExecutionSpec
impl StructuralPartialEq for ExecutionSpec