#[non_exhaustive]pub struct InfrastructureSpec {
pub resources: Option<Resources>,
pub runtime: Option<Runtime>,
pub network: Option<Network>,
/* private fields */
}Expand description
Configuration for the underlying infrastructure used to run workloads.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resources: Option<Resources>Hardware config.
runtime: Option<Runtime>Software config.
network: Option<Network>Networking config.
Implementations
Sourceimpl InfrastructureSpec
impl InfrastructureSpec
Sourcepub fn set_resources<T: Into<Option<Resources>>>(self, v: T) -> Self
pub fn set_resources<T: Into<Option<Resources>>>(self, v: T) -> Self
Sets the value of resources.
Note that all the setters affecting resources are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::task::infrastructure_spec::BatchComputeResources;
let x = InfrastructureSpec::new().set_resources(Some(
google_cloud_dataplex_v1::model::task::infrastructure_spec::Resources::Batch(BatchComputeResources::default().into())));Sourcepub fn batch(&self) -> Option<&Box<BatchComputeResources>>
pub fn batch(&self) -> Option<&Box<BatchComputeResources>>
The value of resources
if it holds a Batch, None if the field is not set or
holds a different branch.
Sourcepub fn set_batch<T: Into<Box<BatchComputeResources>>>(self, v: T) -> Self
pub fn set_batch<T: Into<Box<BatchComputeResources>>>(self, v: T) -> Self
Sets the value of resources
to hold a Batch.
Note that all the setters affecting resources are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::task::infrastructure_spec::BatchComputeResources;
let x = InfrastructureSpec::new().set_batch(BatchComputeResources::default()/* use setters */);
assert!(x.batch().is_some());Sourcepub fn set_runtime<T: Into<Option<Runtime>>>(self, v: T) -> Self
pub fn set_runtime<T: Into<Option<Runtime>>>(self, v: T) -> Self
Sets the value of runtime.
Note that all the setters affecting runtime are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::task::infrastructure_spec::ContainerImageRuntime;
let x = InfrastructureSpec::new().set_runtime(Some(
google_cloud_dataplex_v1::model::task::infrastructure_spec::Runtime::ContainerImage(ContainerImageRuntime::default().into())));Sourcepub fn container_image(&self) -> Option<&Box<ContainerImageRuntime>>
pub fn container_image(&self) -> Option<&Box<ContainerImageRuntime>>
The value of runtime
if it holds a ContainerImage, None if the field is not set or
holds a different branch.
Sourcepub fn set_container_image<T: Into<Box<ContainerImageRuntime>>>(
self,
v: T,
) -> Self
pub fn set_container_image<T: Into<Box<ContainerImageRuntime>>>( self, v: T, ) -> Self
Sets the value of runtime
to hold a ContainerImage.
Note that all the setters affecting runtime are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::task::infrastructure_spec::ContainerImageRuntime;
let x = InfrastructureSpec::new().set_container_image(ContainerImageRuntime::default()/* use setters */);
assert!(x.container_image().is_some());Sourcepub fn set_network<T: Into<Option<Network>>>(self, v: T) -> Self
pub fn set_network<T: Into<Option<Network>>>(self, v: T) -> Self
Sets the value of network.
Note that all the setters affecting network are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::task::infrastructure_spec::VpcNetwork;
let x = InfrastructureSpec::new().set_network(Some(
google_cloud_dataplex_v1::model::task::infrastructure_spec::Network::VpcNetwork(VpcNetwork::default().into())));Sourcepub fn vpc_network(&self) -> Option<&Box<VpcNetwork>>
pub fn vpc_network(&self) -> Option<&Box<VpcNetwork>>
The value of network
if it holds a VpcNetwork, None if the field is not set or
holds a different branch.
Sourcepub fn set_vpc_network<T: Into<Box<VpcNetwork>>>(self, v: T) -> Self
pub fn set_vpc_network<T: Into<Box<VpcNetwork>>>(self, v: T) -> Self
Sets the value of network
to hold a VpcNetwork.
Note that all the setters affecting network are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::task::infrastructure_spec::VpcNetwork;
let x = InfrastructureSpec::new().set_vpc_network(VpcNetwork::default()/* use setters */);
assert!(x.vpc_network().is_some());Trait Implementations
Sourceimpl Clone for InfrastructureSpec
impl Clone for InfrastructureSpec
Sourcefn clone(&self) -> InfrastructureSpec
fn clone(&self) -> InfrastructureSpec
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for InfrastructureSpec
impl Debug for InfrastructureSpec
Sourceimpl Default for InfrastructureSpec
impl Default for InfrastructureSpec
Sourcefn default() -> InfrastructureSpec
fn default() -> InfrastructureSpec
Sourceimpl Message for InfrastructureSpec
impl Message for InfrastructureSpec
Sourceimpl PartialEq for InfrastructureSpec
impl PartialEq for InfrastructureSpec
impl StructuralPartialEq for InfrastructureSpec