#[non_exhaustive]pub struct OneTime {
pub ttl_after_scan_completion: Option<Duration>,
/* private fields */
}Expand description
The scan runs once using create API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ttl_after_scan_completion: Option<Duration>Optional. Time to live for OneTime scans. default value is 24 hours, minimum value is 0 seconds, and maximum value is 365 days. The time is calculated from the data scan job completion time. If value is set as 0 seconds, the scan will be immediately deleted upon job completion, regardless of whether the job succeeded or failed.
Implementations
Sourceimpl OneTime
impl OneTime
pub fn new() -> Self
Sourcepub fn set_ttl_after_scan_completion<T>(self, v: T) -> Self
pub fn set_ttl_after_scan_completion<T>(self, v: T) -> Self
Sets the value of ttl_after_scan_completion.
Example
ⓘ
use wkt::Duration;
let x = OneTime::new().set_ttl_after_scan_completion(Duration::default()/* use setters */);Sourcepub fn set_or_clear_ttl_after_scan_completion<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ttl_after_scan_completion<T>(self, v: Option<T>) -> Self
Sets or clears the value of ttl_after_scan_completion.
Example
ⓘ
use wkt::Duration;
let x = OneTime::new().set_or_clear_ttl_after_scan_completion(Some(Duration::default()/* use setters */));
let x = OneTime::new().set_or_clear_ttl_after_scan_completion(None::<Duration>);Trait Implementations
impl StructuralPartialEq for OneTime