#[non_exhaustive]pub struct StorageConfig {
pub include_patterns: Vec<String>,
pub exclude_patterns: Vec<String>,
pub csv_options: Option<CsvOptions>,
pub json_options: Option<JsonOptions>,
pub unstructured_data_options: Option<UnstructuredDataOptions>,
/* private fields */
}Expand description
Configurations related to Cloud Storage as the data source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.include_patterns: Vec<String>Optional. Defines the data to include during discovery when only a subset of the data should be considered. Provide a list of patterns that identify the data to include. For Cloud Storage bucket assets, these patterns are interpreted as glob patterns used to match object names. For BigQuery dataset assets, these patterns are interpreted as patterns to match table names.
exclude_patterns: Vec<String>Optional. Defines the data to exclude during discovery. Provide a list of patterns that identify the data to exclude. For Cloud Storage bucket assets, these patterns are interpreted as glob patterns used to match object names. For BigQuery dataset assets, these patterns are interpreted as patterns to match table names.
csv_options: Option<CsvOptions>Optional. Configuration for CSV data.
json_options: Option<JsonOptions>Optional. Configuration for JSON data.
unstructured_data_options: Option<UnstructuredDataOptions>Optional. Specifies configuration for unstructured data discovery.
Implementations
Sourceimpl StorageConfig
impl StorageConfig
Sourcepub fn set_include_patterns<T, V>(self, v: T) -> Self
pub fn set_include_patterns<T, V>(self, v: T) -> Self
Sets the value of include_patterns.
Example
let x = StorageConfig::new().set_include_patterns(["a", "b", "c"]);Sourcepub fn set_exclude_patterns<T, V>(self, v: T) -> Self
pub fn set_exclude_patterns<T, V>(self, v: T) -> Self
Sets the value of exclude_patterns.
Example
let x = StorageConfig::new().set_exclude_patterns(["a", "b", "c"]);Sourcepub fn set_csv_options<T>(self, v: T) -> Selfwhere
T: Into<CsvOptions>,
pub fn set_csv_options<T>(self, v: T) -> Selfwhere
T: Into<CsvOptions>,
Sets the value of csv_options.
Example
use google_cloud_dataplex_v1::model::data_discovery_spec::storage_config::CsvOptions;
let x = StorageConfig::new().set_csv_options(CsvOptions::default()/* use setters */);Sourcepub fn set_or_clear_csv_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<CsvOptions>,
pub fn set_or_clear_csv_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<CsvOptions>,
Sets or clears the value of csv_options.
Example
use google_cloud_dataplex_v1::model::data_discovery_spec::storage_config::CsvOptions;
let x = StorageConfig::new().set_or_clear_csv_options(Some(CsvOptions::default()/* use setters */));
let x = StorageConfig::new().set_or_clear_csv_options(None::<CsvOptions>);Sourcepub fn set_json_options<T>(self, v: T) -> Selfwhere
T: Into<JsonOptions>,
pub fn set_json_options<T>(self, v: T) -> Selfwhere
T: Into<JsonOptions>,
Sets the value of json_options.
Example
use google_cloud_dataplex_v1::model::data_discovery_spec::storage_config::JsonOptions;
let x = StorageConfig::new().set_json_options(JsonOptions::default()/* use setters */);Sourcepub fn set_or_clear_json_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<JsonOptions>,
pub fn set_or_clear_json_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<JsonOptions>,
Sets or clears the value of json_options.
Example
use google_cloud_dataplex_v1::model::data_discovery_spec::storage_config::JsonOptions;
let x = StorageConfig::new().set_or_clear_json_options(Some(JsonOptions::default()/* use setters */));
let x = StorageConfig::new().set_or_clear_json_options(None::<JsonOptions>);Sourcepub fn set_unstructured_data_options<T>(self, v: T) -> Selfwhere
T: Into<UnstructuredDataOptions>,
pub fn set_unstructured_data_options<T>(self, v: T) -> Selfwhere
T: Into<UnstructuredDataOptions>,
Sets the value of unstructured_data_options.
Example
use google_cloud_dataplex_v1::model::data_discovery_spec::storage_config::UnstructuredDataOptions;
let x = StorageConfig::new().set_unstructured_data_options(UnstructuredDataOptions::default()/* use setters */);Sourcepub fn set_or_clear_unstructured_data_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<UnstructuredDataOptions>,
pub fn set_or_clear_unstructured_data_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<UnstructuredDataOptions>,
Sets or clears the value of unstructured_data_options.
Example
use google_cloud_dataplex_v1::model::data_discovery_spec::storage_config::UnstructuredDataOptions;
let x = StorageConfig::new().set_or_clear_unstructured_data_options(Some(UnstructuredDataOptions::default()/* use setters */));
let x = StorageConfig::new().set_or_clear_unstructured_data_options(None::<UnstructuredDataOptions>);Trait Implementations
Sourceimpl Clone for StorageConfig
impl Clone for StorageConfig
Sourcefn clone(&self) -> StorageConfig
fn clone(&self) -> StorageConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for StorageConfig
impl Debug for StorageConfig
Sourceimpl Default for StorageConfig
impl Default for StorageConfig
Sourcefn default() -> StorageConfig
fn default() -> StorageConfig
Sourceimpl Message for StorageConfig
impl Message for StorageConfig
Sourceimpl PartialEq for StorageConfig
impl PartialEq for StorageConfig
impl StructuralPartialEq for StorageConfig