#[non_exhaustive]pub struct DebugQuery {
pub description: String,
pub sql_statement: String,
/* private fields */
}Expand description
Specifies a SQL statement that is evaluated to return up to 10 scalar values that are used to debug rules. If the rule fails, the values can help diagnose the cause of the failure.
The SQL statement must use GoogleSQL syntax, and must not contain any semicolons.
You can use the data reference parameter ${data()} to reference the
source table with all of its precondition filters applied. Examples of
precondition filters include row filters, incremental data filters, and
sampling. For more information, see Data reference
parameter.
You can also name results with an explicit alias using [AS] alias. For
more information, see BigQuery explicit
aliases.
Example: SELECT MIN(col1) AS min_col1, MAX(col1) AS max_col1 FROM ${data()}
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: StringOptional. Specifies the description of the debug query.
- The maximum length is 1,024 characters.
sql_statement: StringRequired. Specifies the SQL statement to be executed.
Implementations
Sourceimpl DebugQuery
impl DebugQuery
pub fn new() -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_sql_statement<T: Into<String>>(self, v: T) -> Self
pub fn set_sql_statement<T: Into<String>>(self, v: T) -> Self