TemplateReference

Struct TemplateReference 

#[non_exhaustive]
pub struct TemplateReference { pub name: String, pub values: HashMap<String, ParameterValue>, pub resolved_sql: String, pub rule_template: Option<DataQualityRuleTemplate>, /* private fields */ }
A rule that constructs a SQL statement to evaluate using a rule template and parameter values. If the constructed statement returns any rows, this rule fails

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The template entry name. Entry must be of EntryType projects/dataplex-types/locations/global/entryTypes/data-quality-rule-template and contains top-level aspect of AspectType projects/dataplex-types/locations/global/aspectTypes/data-quality-rule-template. The format is: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}

values: HashMap<String, ParameterValue>

Optional. Provides the map of parameter name and value. The maximum size of the field is 120KB (encoded as UTF-8).

resolved_sql: String

Output only. The resolved SQL statement generated from the template with parameters substituted. It is only populated in the result.

rule_template: Option<DataQualityRuleTemplate>

Output only. The rule template used to resolve the rule. It is only populated in the result.

Implementations

Source

impl TemplateReference

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = TemplateReference::new().set_name(format!("projects/{project_id}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}"));
pub fn set_values<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<ParameterValue>,

Sets the value of values.

Example
use google_cloud_dataplex_v1::model::data_quality_rule::template_reference::ParameterValue;
let x = TemplateReference::new().set_values([
    ("key0", ParameterValue::default()/* use setters */),
    ("key1", ParameterValue::default()/* use (different) setters */),
]);
pub fn set_resolved_sql<T: Into<String>>(self, v: T) -> Self

Sets the value of resolved_sql.

Example
let x = TemplateReference::new().set_resolved_sql("example");
pub fn set_rule_template<T>(self, v: T) -> Self

Sets the value of rule_template.

Example
use google_cloud_dataplex_v1::model::DataQualityRuleTemplate;
let x = TemplateReference::new().set_rule_template(DataQualityRuleTemplate::default()/* use setters */);
pub fn set_or_clear_rule_template<T>(self, v: Option<T>) -> Self

Sets or clears the value of rule_template.

Example
use google_cloud_dataplex_v1::model::DataQualityRuleTemplate;
let x = TemplateReference::new().set_or_clear_rule_template(Some(DataQualityRuleTemplate::default()/* use setters */));
let x = TemplateReference::new().set_or_clear_rule_template(None::<DataQualityRuleTemplate>);