#[non_exhaustive]pub struct Asset {Show 13 fields
pub name: String,
pub display_name: String,
pub uid: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub description: String,
pub state: State,
pub resource_spec: Option<ResourceSpec>,
pub resource_status: Option<ResourceStatus>,
pub security_status: Option<SecurityStatus>,
pub discovery_spec: Option<DiscoverySpec>,
pub discovery_status: Option<DiscoveryStatus>,
/* private fields */
}Expand description
An asset represents a cloud resource that is being managed within a lake as a member of a zone.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The relative resource name of the asset, of the form:
projects/{project_number}/locations/{location_id}/lakes/{lake_id}/zones/{zone_id}/assets/{asset_id}.
display_name: StringOptional. User friendly display name.
uid: StringOutput only. System generated globally unique ID for the asset. This ID will be different if the asset is deleted and re-created with the same name.
create_time: Option<Timestamp>Output only. The time when the asset was created.
update_time: Option<Timestamp>Output only. The time when the asset was last updated.
labels: HashMap<String, String>Optional. User defined labels for the asset.
description: StringOptional. Description of the asset.
state: StateOutput only. Current state of the asset.
resource_spec: Option<ResourceSpec>Required. Specification of the resource that is referenced by this asset.
resource_status: Option<ResourceStatus>Output only. Status of the resource referenced by this asset.
security_status: Option<SecurityStatus>Output only. Status of the security policy applied to resource referenced by this asset.
discovery_spec: Option<DiscoverySpec>Optional. Specification of the discovery feature applied to data referenced by this asset. When this spec is left unset, the asset will use the spec set on the parent zone.
discovery_status: Option<DiscoveryStatus>Output only. Status of the discovery feature applied to data referenced by this asset.
Implementations
Sourceimpl Asset
impl Asset
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Asset::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Asset::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Asset::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Asset::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Asset::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Asset::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_resource_spec<T>(self, v: T) -> Selfwhere
T: Into<ResourceSpec>,
pub fn set_resource_spec<T>(self, v: T) -> Selfwhere
T: Into<ResourceSpec>,
Sets the value of resource_spec.
Example
use google_cloud_dataplex_v1::model::asset::ResourceSpec;
let x = Asset::new().set_resource_spec(ResourceSpec::default()/* use setters */);Sourcepub fn set_or_clear_resource_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceSpec>,
pub fn set_or_clear_resource_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceSpec>,
Sets or clears the value of resource_spec.
Example
use google_cloud_dataplex_v1::model::asset::ResourceSpec;
let x = Asset::new().set_or_clear_resource_spec(Some(ResourceSpec::default()/* use setters */));
let x = Asset::new().set_or_clear_resource_spec(None::<ResourceSpec>);Sourcepub fn set_resource_status<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatus>,
pub fn set_resource_status<T>(self, v: T) -> Selfwhere
T: Into<ResourceStatus>,
Sets the value of resource_status.
Example
use google_cloud_dataplex_v1::model::asset::ResourceStatus;
let x = Asset::new().set_resource_status(ResourceStatus::default()/* use setters */);Sourcepub fn set_or_clear_resource_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatus>,
pub fn set_or_clear_resource_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<ResourceStatus>,
Sets or clears the value of resource_status.
Example
use google_cloud_dataplex_v1::model::asset::ResourceStatus;
let x = Asset::new().set_or_clear_resource_status(Some(ResourceStatus::default()/* use setters */));
let x = Asset::new().set_or_clear_resource_status(None::<ResourceStatus>);Sourcepub fn set_security_status<T>(self, v: T) -> Selfwhere
T: Into<SecurityStatus>,
pub fn set_security_status<T>(self, v: T) -> Selfwhere
T: Into<SecurityStatus>,
Sets the value of security_status.
Example
use google_cloud_dataplex_v1::model::asset::SecurityStatus;
let x = Asset::new().set_security_status(SecurityStatus::default()/* use setters */);Sourcepub fn set_or_clear_security_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityStatus>,
pub fn set_or_clear_security_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<SecurityStatus>,
Sets or clears the value of security_status.
Example
use google_cloud_dataplex_v1::model::asset::SecurityStatus;
let x = Asset::new().set_or_clear_security_status(Some(SecurityStatus::default()/* use setters */));
let x = Asset::new().set_or_clear_security_status(None::<SecurityStatus>);Sourcepub fn set_discovery_spec<T>(self, v: T) -> Selfwhere
T: Into<DiscoverySpec>,
pub fn set_discovery_spec<T>(self, v: T) -> Selfwhere
T: Into<DiscoverySpec>,
Sets the value of discovery_spec.
Example
use google_cloud_dataplex_v1::model::asset::DiscoverySpec;
let x = Asset::new().set_discovery_spec(DiscoverySpec::default()/* use setters */);Sourcepub fn set_or_clear_discovery_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiscoverySpec>,
pub fn set_or_clear_discovery_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiscoverySpec>,
Sets or clears the value of discovery_spec.
Example
use google_cloud_dataplex_v1::model::asset::DiscoverySpec;
let x = Asset::new().set_or_clear_discovery_spec(Some(DiscoverySpec::default()/* use setters */));
let x = Asset::new().set_or_clear_discovery_spec(None::<DiscoverySpec>);Sourcepub fn set_discovery_status<T>(self, v: T) -> Selfwhere
T: Into<DiscoveryStatus>,
pub fn set_discovery_status<T>(self, v: T) -> Selfwhere
T: Into<DiscoveryStatus>,
Sets the value of discovery_status.
Example
use google_cloud_dataplex_v1::model::asset::DiscoveryStatus;
let x = Asset::new().set_discovery_status(DiscoveryStatus::default()/* use setters */);Sourcepub fn set_or_clear_discovery_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiscoveryStatus>,
pub fn set_or_clear_discovery_status<T>(self, v: Option<T>) -> Selfwhere
T: Into<DiscoveryStatus>,
Sets or clears the value of discovery_status.
Example
use google_cloud_dataplex_v1::model::asset::DiscoveryStatus;
let x = Asset::new().set_or_clear_discovery_status(Some(DiscoveryStatus::default()/* use setters */));
let x = Asset::new().set_or_clear_discovery_status(None::<DiscoveryStatus>);