DataAttributeBinding

Struct DataAttributeBinding 

#[non_exhaustive]
pub struct DataAttributeBinding { pub name: String, pub uid: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub description: String, pub display_name: String, pub labels: HashMap<String, String>, pub etag: String, pub attributes: Vec<String>, pub paths: Vec<Path>, pub resource_reference: Option<ResourceReference>, /* private fields */ }
👎Deprecated
DataAttributeBinding represents binding of attributes to resources. Eg: Bind ‘CustomerInfo’ entity with ‘PII’ attribute.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String
👎Deprecated

Output only. The relative resource name of the Data Attribute Binding, of the form: projects/{project_number}/locations/{location}/dataAttributeBindings/{data_attribute_binding_id}

uid: String
👎Deprecated

Output only. System generated globally unique ID for the DataAttributeBinding. This ID will be different if the DataAttributeBinding is deleted and re-created with the same name.

create_time: Option<Timestamp>
👎Deprecated

Output only. The time when the DataAttributeBinding was created.

update_time: Option<Timestamp>
👎Deprecated

Output only. The time when the DataAttributeBinding was last updated.

description: String
👎Deprecated

Optional. Description of the DataAttributeBinding.

display_name: String
👎Deprecated

Optional. User friendly display name.

labels: HashMap<String, String>
👎Deprecated

Optional. User-defined labels for the DataAttributeBinding.

etag: String
👎Deprecated

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Etags must be used when calling the DeleteDataAttributeBinding and the UpdateDataAttributeBinding method.

attributes: Vec<String>
👎Deprecated

Optional. List of attributes to be associated with the resource, provided in the form: projects/{project}/locations/{location}/dataTaxonomies/{dataTaxonomy}/attributes/{data_attribute_id}

paths: Vec<Path>
👎Deprecated

Optional. The list of paths for items within the associated resource (eg. columns and partitions within a table) along with attribute bindings.

resource_reference: Option<ResourceReference>
👎Deprecated

The reference to the resource that is associated to attributes, or the query to match resources and associate attributes.

Implementations

Source

impl DataAttributeBinding

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DataAttributeBinding::new().set_name("example");
pub fn set_uid<T: Into<String>>(self, v: T) -> Self

Sets the value of uid.

Example
let x = DataAttributeBinding::new().set_uid("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = DataAttributeBinding::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = DataAttributeBinding::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataAttributeBinding::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = DataAttributeBinding::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = DataAttributeBinding::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataAttributeBinding::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_description<T: Into<String>>(self, v: T) -> Self

Sets the value of description.

Example
let x = DataAttributeBinding::new().set_description("example");
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = DataAttributeBinding::new().set_display_name("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = DataAttributeBinding::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = DataAttributeBinding::new().set_etag("example");
pub fn set_attributes<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of attributes.

Example
let x = DataAttributeBinding::new().set_attributes(["a", "b", "c"]);
pub fn set_paths<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Path>,

Sets the value of paths.

Example
use google_cloud_dataplex_v1::model::data_attribute_binding::Path;
let x = DataAttributeBinding::new()
    .set_paths([
        Path::default()/* use setters */,
        Path::default()/* use (different) setters */,
    ]);
pub fn set_resource_reference<T: Into<Option<ResourceReference>>>( self, v: T, ) -> Self

Sets the value of resource_reference.

Note that all the setters affecting resource_reference are mutually exclusive.

Example
use google_cloud_dataplex_v1::model::data_attribute_binding::ResourceReference;
let x = DataAttributeBinding::new().set_resource_reference(Some(ResourceReference::Resource("example".to_string())));
pub fn resource(&self) -> Option<&String>

The value of resource_reference if it holds a Resource, None if the field is not set or holds a different branch.

pub fn set_resource<T: Into<String>>(self, v: T) -> Self

Sets the value of resource_reference to hold a Resource.

Note that all the setters affecting resource_reference are mutually exclusive.

Example
let x = DataAttributeBinding::new().set_resource("example");
assert!(x.resource().is_some());