#[non_exhaustive]pub struct DataDocumentationSpec {
pub catalog_publishing_enabled: bool,
pub generation_scopes: Vec<GenerationScope>,
/* private fields */
}Expand description
DataDocumentation scan related spec.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_publishing_enabled: boolOptional. Whether to publish result to Dataplex Catalog.
generation_scopes: Vec<GenerationScope>Optional. Specifies which components of the data documentation to generate. Any component that is required to generate the specified components will also be generated. If no generation scope is specified, all available documentation components will be generated.
Implementations
Sourceimpl DataDocumentationSpec
impl DataDocumentationSpec
pub fn new() -> Self
Sourcepub fn set_catalog_publishing_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_catalog_publishing_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of catalog_publishing_enabled.
Example
ⓘ
let x = DataDocumentationSpec::new().set_catalog_publishing_enabled(true);Sourcepub fn set_generation_scopes<T, V>(self, v: T) -> Self
pub fn set_generation_scopes<T, V>(self, v: T) -> Self
Sets the value of generation_scopes.
Example
ⓘ
use google_cloud_dataplex_v1::model::data_documentation_spec::GenerationScope;
let x = DataDocumentationSpec::new().set_generation_scopes([
GenerationScope::All,
GenerationScope::TableAndColumnDescriptions,
GenerationScope::SqlQueries,
]);Trait Implementations
Sourceimpl Clone for DataDocumentationSpec
impl Clone for DataDocumentationSpec
Sourcefn clone(&self) -> DataDocumentationSpec
fn clone(&self) -> DataDocumentationSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataDocumentationSpec
impl Debug for DataDocumentationSpec
Sourceimpl Default for DataDocumentationSpec
impl Default for DataDocumentationSpec
Sourcefn default() -> DataDocumentationSpec
fn default() -> DataDocumentationSpec
Returns the “default value” for a type. Read more
Sourceimpl Message for DataDocumentationSpec
impl Message for DataDocumentationSpec
Sourceimpl PartialEq for DataDocumentationSpec
impl PartialEq for DataDocumentationSpec
impl StructuralPartialEq for DataDocumentationSpec