DataQualityResult

Struct DataQualityResult 

#[non_exhaustive]
pub struct DataQualityResult { pub passed: bool, pub score: Option<f32>, pub dimensions: Vec<DataQualityDimensionResult>, pub columns: Vec<DataQualityColumnResult>, pub rules: Vec<DataQualityRuleResult>, pub row_count: i64, pub scanned_data: Option<ScannedData>, pub post_scan_actions_result: Option<PostScanActionsResult>, pub catalog_publishing_status: Option<DataScanCatalogPublishingStatus>, pub anomaly_detection_generated_assets: Option<AnomalyDetectionGeneratedAssets>, /* private fields */ }
The output of a DataQualityScan.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
passed: bool

Output only. Overall data quality result – true if all rules passed.

score: Option<f32>

Output only. The overall data quality score.

The score ranges between [0, 100] (up to two decimal points).

dimensions: Vec<DataQualityDimensionResult>

Output only. A list of results at the dimension level.

A dimension will have a corresponding DataQualityDimensionResult if and only if there is at least one rule with the ‘dimension’ field set to it.

columns: Vec<DataQualityColumnResult>

Output only. A list of results at the column level.

A column will have a corresponding DataQualityColumnResult if and only if there is at least one rule with the ‘column’ field set to it.

rules: Vec<DataQualityRuleResult>

Output only. A list of all the rules in a job, and their results.

row_count: i64

Output only. The count of rows processed.

scanned_data: Option<ScannedData>

Output only. The data scanned for this result.

post_scan_actions_result: Option<PostScanActionsResult>

Output only. The result of post scan actions.

catalog_publishing_status: Option<DataScanCatalogPublishingStatus>

Output only. The status of publishing the data scan as Dataplex Universal Catalog metadata.

anomaly_detection_generated_assets: Option<AnomalyDetectionGeneratedAssets>

Output only. The generated assets for anomaly detection.

Implementations

Source

impl DataQualityResult

pub fn new() -> Self

pub fn set_passed<T: Into<bool>>(self, v: T) -> Self

Sets the value of passed.

Example
let x = DataQualityResult::new().set_passed(true);
pub fn set_score<T>(self, v: T) -> Self
where T: Into<f32>,

Sets the value of score.

Example
let x = DataQualityResult::new().set_score(42.0);
pub fn set_or_clear_score<T>(self, v: Option<T>) -> Self
where T: Into<f32>,

Sets or clears the value of score.

Example
let x = DataQualityResult::new().set_or_clear_score(Some(42.0));
let x = DataQualityResult::new().set_or_clear_score(None::<f32>);
pub fn set_dimensions<T, V>(self, v: T) -> Self

Sets the value of dimensions.

Example
use google_cloud_dataplex_v1::model::DataQualityDimensionResult;
let x = DataQualityResult::new()
    .set_dimensions([
        DataQualityDimensionResult::default()/* use setters */,
        DataQualityDimensionResult::default()/* use (different) setters */,
    ]);
pub fn set_columns<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<DataQualityColumnResult>,

Sets the value of columns.

Example
use google_cloud_dataplex_v1::model::DataQualityColumnResult;
let x = DataQualityResult::new()
    .set_columns([
        DataQualityColumnResult::default()/* use setters */,
        DataQualityColumnResult::default()/* use (different) setters */,
    ]);
pub fn set_rules<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<DataQualityRuleResult>,

Sets the value of rules.

Example
use google_cloud_dataplex_v1::model::DataQualityRuleResult;
let x = DataQualityResult::new()
    .set_rules([
        DataQualityRuleResult::default()/* use setters */,
        DataQualityRuleResult::default()/* use (different) setters */,
    ]);
pub fn set_row_count<T: Into<i64>>(self, v: T) -> Self

Sets the value of row_count.

Example
let x = DataQualityResult::new().set_row_count(42);
pub fn set_scanned_data<T>(self, v: T) -> Self
where T: Into<ScannedData>,

Sets the value of scanned_data.

Example
use google_cloud_dataplex_v1::model::ScannedData;
let x = DataQualityResult::new().set_scanned_data(ScannedData::default()/* use setters */);
pub fn set_or_clear_scanned_data<T>(self, v: Option<T>) -> Self
where T: Into<ScannedData>,

Sets or clears the value of scanned_data.

Example
use google_cloud_dataplex_v1::model::ScannedData;
let x = DataQualityResult::new().set_or_clear_scanned_data(Some(ScannedData::default()/* use setters */));
let x = DataQualityResult::new().set_or_clear_scanned_data(None::<ScannedData>);
pub fn set_post_scan_actions_result<T>(self, v: T) -> Self

Sets the value of post_scan_actions_result.

Example
use google_cloud_dataplex_v1::model::data_quality_result::PostScanActionsResult;
let x = DataQualityResult::new().set_post_scan_actions_result(PostScanActionsResult::default()/* use setters */);
pub fn set_or_clear_post_scan_actions_result<T>(self, v: Option<T>) -> Self

Sets or clears the value of post_scan_actions_result.

Example
use google_cloud_dataplex_v1::model::data_quality_result::PostScanActionsResult;
let x = DataQualityResult::new().set_or_clear_post_scan_actions_result(Some(PostScanActionsResult::default()/* use setters */));
let x = DataQualityResult::new().set_or_clear_post_scan_actions_result(None::<PostScanActionsResult>);
pub fn set_catalog_publishing_status<T>(self, v: T) -> Self

Sets the value of catalog_publishing_status.

Example
use google_cloud_dataplex_v1::model::DataScanCatalogPublishingStatus;
let x = DataQualityResult::new().set_catalog_publishing_status(DataScanCatalogPublishingStatus::default()/* use setters */);
pub fn set_or_clear_catalog_publishing_status<T>(self, v: Option<T>) -> Self

Sets or clears the value of catalog_publishing_status.

Example
use google_cloud_dataplex_v1::model::DataScanCatalogPublishingStatus;
let x = DataQualityResult::new().set_or_clear_catalog_publishing_status(Some(DataScanCatalogPublishingStatus::default()/* use setters */));
let x = DataQualityResult::new().set_or_clear_catalog_publishing_status(None::<DataScanCatalogPublishingStatus>);
pub fn set_anomaly_detection_generated_assets<T>(self, v: T) -> Self

Sets the value of anomaly_detection_generated_assets.

Example
use google_cloud_dataplex_v1::model::data_quality_result::AnomalyDetectionGeneratedAssets;
let x = DataQualityResult::new().set_anomaly_detection_generated_assets(AnomalyDetectionGeneratedAssets::default()/* use setters */);
pub fn set_or_clear_anomaly_detection_generated_assets<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of anomaly_detection_generated_assets.

Example
use google_cloud_dataplex_v1::model::data_quality_result::AnomalyDetectionGeneratedAssets;
let x = DataQualityResult::new().set_or_clear_anomaly_detection_generated_assets(Some(AnomalyDetectionGeneratedAssets::default()/* use setters */));
let x = DataQualityResult::new().set_or_clear_anomaly_detection_generated_assets(None::<AnomalyDetectionGeneratedAssets>);