#[non_exhaustive]pub struct DataQualityRuleResult {
pub rule: Option<DataQualityRule>,
pub passed: bool,
pub evaluated_count: i64,
pub passed_count: i64,
pub null_count: i64,
pub pass_ratio: f64,
pub failing_rows_query: String,
pub assertion_row_count: i64,
pub debug_queries_result_sets: Vec<DebugQueryResultSet>,
/* private fields */
}Expand description
DataQualityRuleResult provides a more detailed, per-rule view of the results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule: Option<DataQualityRule>Output only. The rule specified in the DataQualitySpec, as is.
passed: boolOutput only. Whether the rule passed or failed.
evaluated_count: i64Output only. The number of rows a rule was evaluated against.
This field is only valid for row-level type rules.
Evaluated count can be configured to either
- include all rows (default) - with
nullrows automatically failing rule evaluation, or - exclude
nullrows from theevaluated_count, by settingignore_nulls = true.
This field is not set for rule SqlAssertion.
passed_count: i64Output only. The number of rows which passed a rule evaluation.
This field is only valid for row-level type rules.
This field is not set for rule SqlAssertion.
null_count: i64Output only. The number of rows with null values in the specified column.
pass_ratio: f64Output only. The ratio of passed_count / evaluated_count.
This field is only valid for row-level type rules.
failing_rows_query: StringOutput only. The query to find rows that did not pass this rule.
This field is only valid for row-level type rules.
assertion_row_count: i64Output only. The number of rows returned by the SQL statement in a SQL assertion rule.
This field is only valid for SQL assertion rules.
debug_queries_result_sets: Vec<DebugQueryResultSet>Output only. Contains the results of all debug queries for this rule. The number of result sets will correspond to the number of debug_queries.
Implementations
Sourceimpl DataQualityRuleResult
impl DataQualityRuleResult
pub fn new() -> Self
Sourcepub fn set_rule<T>(self, v: T) -> Selfwhere
T: Into<DataQualityRule>,
pub fn set_rule<T>(self, v: T) -> Selfwhere
T: Into<DataQualityRule>,
Sourcepub fn set_or_clear_rule<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataQualityRule>,
pub fn set_or_clear_rule<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataQualityRule>,
Sourcepub fn set_passed<T: Into<bool>>(self, v: T) -> Self
pub fn set_passed<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_evaluated_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_evaluated_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of evaluated_count.
Example
let x = DataQualityRuleResult::new().set_evaluated_count(42);Sourcepub fn set_passed_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_passed_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of passed_count.
Example
let x = DataQualityRuleResult::new().set_passed_count(42);Sourcepub fn set_null_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_null_count<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_pass_ratio<T: Into<f64>>(self, v: T) -> Self
pub fn set_pass_ratio<T: Into<f64>>(self, v: T) -> Self
Sourcepub fn set_failing_rows_query<T: Into<String>>(self, v: T) -> Self
pub fn set_failing_rows_query<T: Into<String>>(self, v: T) -> Self
Sets the value of failing_rows_query.
Example
let x = DataQualityRuleResult::new().set_failing_rows_query("example");Sourcepub fn set_assertion_row_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_assertion_row_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of assertion_row_count.
Example
let x = DataQualityRuleResult::new().set_assertion_row_count(42);Sourcepub fn set_debug_queries_result_sets<T, V>(self, v: T) -> Self
pub fn set_debug_queries_result_sets<T, V>(self, v: T) -> Self
Sets the value of debug_queries_result_sets.
Example
use google_cloud_dataplex_v1::model::data_quality_rule_result::DebugQueryResultSet;
let x = DataQualityRuleResult::new()
.set_debug_queries_result_sets([
DebugQueryResultSet::default()/* use setters */,
DebugQueryResultSet::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for DataQualityRuleResult
impl Clone for DataQualityRuleResult
Sourcefn clone(&self) -> DataQualityRuleResult
fn clone(&self) -> DataQualityRuleResult
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more