#[non_exhaustive]pub struct DataQualitySpec {
pub rules: Vec<DataQualityRule>,
pub sampling_percent: f32,
pub row_filter: String,
pub post_scan_actions: Option<PostScanActions>,
pub catalog_publishing_enabled: bool,
pub enable_catalog_based_rules: bool,
pub filter: String,
/* private fields */
}Expand description
DataQualityScan related setting.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rules: Vec<DataQualityRule>Required. The list of rules to evaluate against a data source. At least one rule is required.
sampling_percent: f32Optional. The percentage of the records to be selected from the dataset for DataScan.
- Value can range between 0.0 and 100.0 with up to 3 significant decimal digits.
- Sampling is not applied if
sampling_percentis not specified, 0 or
row_filter: StringOptional. A filter applied to all rows in a single DataScan job. The filter needs to be a valid SQL expression for a WHERE clause in GoogleSQL syntax.
Example: col1 >= 0 AND col2 < 10
post_scan_actions: Option<PostScanActions>Optional. Actions to take upon job completion.
catalog_publishing_enabled: boolOptional. If set, the latest DataScan job result will be published as Dataplex Universal Catalog metadata.
enable_catalog_based_rules: boolOptional. If enabled, the data scan will retrieve rules defined in the dataplex-types.global.data-rules aspect on all paths of the catalog entry corresponding to the BigQuery table resource and all attached glossary terms. The path that data-rules aspect is attached on the table entry defines the column that the rule will be evaluated against. For glossary terms, the path that the terms are attached on the table entry defines the column that the rule will be evaluated against. At the start of scan execution, the rules reflect the latest state retrieved from the catalog entry and any updates on the rules thereafter are ignored for that execution. The updates will be reflected from the next execution. Rules defined in the datascan must be empty if this field is enabled.
filter: StringOptional. Filter for selectively running a subset of rules. You can filter the request by the name or attribute key-value pairs defined on the rule. If not specified, all rules are run. The filter is applicable to both, the rules retrieved from catalog and explicitly defined rules in the scan. Please see filter syntax for more details.
Implementations
Sourceimpl DataQualitySpec
impl DataQualitySpec
Sourcepub fn set_sampling_percent<T: Into<f32>>(self, v: T) -> Self
pub fn set_sampling_percent<T: Into<f32>>(self, v: T) -> Self
Sets the value of sampling_percent.
Example
let x = DataQualitySpec::new().set_sampling_percent(42.0);Sourcepub fn set_row_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_row_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_post_scan_actions<T>(self, v: T) -> Selfwhere
T: Into<PostScanActions>,
pub fn set_post_scan_actions<T>(self, v: T) -> Selfwhere
T: Into<PostScanActions>,
Sets the value of post_scan_actions.
Example
use google_cloud_dataplex_v1::model::data_quality_spec::PostScanActions;
let x = DataQualitySpec::new().set_post_scan_actions(PostScanActions::default()/* use setters */);Sourcepub fn set_or_clear_post_scan_actions<T>(self, v: Option<T>) -> Selfwhere
T: Into<PostScanActions>,
pub fn set_or_clear_post_scan_actions<T>(self, v: Option<T>) -> Selfwhere
T: Into<PostScanActions>,
Sets or clears the value of post_scan_actions.
Example
use google_cloud_dataplex_v1::model::data_quality_spec::PostScanActions;
let x = DataQualitySpec::new().set_or_clear_post_scan_actions(Some(PostScanActions::default()/* use setters */));
let x = DataQualitySpec::new().set_or_clear_post_scan_actions(None::<PostScanActions>);Sourcepub fn set_catalog_publishing_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_catalog_publishing_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of catalog_publishing_enabled.
Example
let x = DataQualitySpec::new().set_catalog_publishing_enabled(true);Sourcepub fn set_enable_catalog_based_rules<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_catalog_based_rules<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_catalog_based_rules.
Example
let x = DataQualitySpec::new().set_enable_catalog_based_rules(true);Trait Implementations
Sourceimpl Clone for DataQualitySpec
impl Clone for DataQualitySpec
Sourcefn clone(&self) -> DataQualitySpec
fn clone(&self) -> DataQualitySpec
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataQualitySpec
impl Debug for DataQualitySpec
Sourceimpl Default for DataQualitySpec
impl Default for DataQualitySpec
Sourcefn default() -> DataQualitySpec
fn default() -> DataQualitySpec
Sourceimpl Message for DataQualitySpec
impl Message for DataQualitySpec
Sourceimpl PartialEq for DataQualitySpec
impl PartialEq for DataQualitySpec
impl StructuralPartialEq for DataQualitySpec