#[non_exhaustive]pub struct EntryLink {
pub name: String,
pub entry_link_type: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub aspects: HashMap<String, Aspect>,
pub entry_references: Vec<EntryReference>,
/* private fields */
}Expand description
EntryLink represents a link between two Entries.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Immutable. Identifier. The relative resource name of the Entry
Link, of the form:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entryLinks/{entry_link_id}
entry_link_type: StringRequired. Immutable. Relative resource name of the Entry Link Type used to create this Entry Link. For example:
- Entry link between synonym terms in a glossary:
projects/dataplex-types/locations/global/entryLinkTypes/synonym - Entry link between related terms in a glossary:
projects/dataplex-types/locations/global/entryLinkTypes/related - Entry link between glossary terms and data assets:
projects/dataplex-types/locations/global/entryLinkTypes/definition
create_time: Option<Timestamp>Output only. The time when the Entry Link was created.
update_time: Option<Timestamp>Output only. The time when the Entry Link was last updated.
aspects: HashMap<String, Aspect>Optional. The aspects that are attached to the entry link.
The format of the aspect key has to be the following:
{project_id_or_number}.{location_id}.{aspect_type_id}
Currently, only a single aspect of a Dataplex-owned Aspect Type is allowed.
entry_references: Vec<EntryReference>Required. Immutable. Specifies the Entries referenced in the Entry Link. There should be exactly two entry references.
Implementations
Sourceimpl EntryLink
impl EntryLink
Sourcepub fn set_entry_link_type<T: Into<String>>(self, v: T) -> Self
pub fn set_entry_link_type<T: Into<String>>(self, v: T) -> Self
Sets the value of entry_link_type.
Example
let x = EntryLink::new().set_entry_link_type("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = EntryLink::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = EntryLink::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = EntryLink::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = EntryLink::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = EntryLink::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = EntryLink::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_aspects<T, K, V>(self, v: T) -> Self
pub fn set_aspects<T, K, V>(self, v: T) -> Self
Sourcepub fn set_entry_references<T, V>(self, v: T) -> Self
pub fn set_entry_references<T, V>(self, v: T) -> Self
Sets the value of entry_references.
Example
use google_cloud_dataplex_v1::model::entry_link::EntryReference;
let x = EntryLink::new()
.set_entry_references([
EntryReference::default()/* use setters */,
EntryReference::default()/* use (different) setters */,
]);