#[non_exhaustive]pub struct ExecutionIdentity {
pub identity: Option<Identity>,
/* private fields */
}Expand description
The identity to run the datascan.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity: Option<Identity>The identity to run the datascan.
Implementations
Sourceimpl ExecutionIdentity
impl ExecutionIdentity
Sourcepub fn set_identity<T: Into<Option<Identity>>>(self, v: T) -> Self
pub fn set_identity<T: Into<Option<Identity>>>(self, v: T) -> Self
Sets the value of identity.
Note that all the setters affecting identity are mutually
exclusive.
Example
use google_cloud_dataplex_v1::model::execution_identity::DataplexServiceAgent;
let x = ExecutionIdentity::new().set_identity(Some(
google_cloud_dataplex_v1::model::execution_identity::Identity::DataplexServiceAgent(DataplexServiceAgent::default().into())));Sourcepub fn dataplex_service_agent(&self) -> Option<&Box<DataplexServiceAgent>>
pub fn dataplex_service_agent(&self) -> Option<&Box<DataplexServiceAgent>>
The value of identity
if it holds a DataplexServiceAgent, None if the field is not set or
holds a different branch.
Sourcepub fn set_dataplex_service_agent<T: Into<Box<DataplexServiceAgent>>>(
self,
v: T,
) -> Self
pub fn set_dataplex_service_agent<T: Into<Box<DataplexServiceAgent>>>( self, v: T, ) -> Self
Sets the value of identity
to hold a DataplexServiceAgent.
Note that all the setters affecting identity are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::execution_identity::DataplexServiceAgent;
let x = ExecutionIdentity::new().set_dataplex_service_agent(DataplexServiceAgent::default()/* use setters */);
assert!(x.dataplex_service_agent().is_some());
assert!(x.user_credential().is_none());
assert!(x.service_account().is_none());Sourcepub fn user_credential(&self) -> Option<&Box<UserCredential>>
pub fn user_credential(&self) -> Option<&Box<UserCredential>>
The value of identity
if it holds a UserCredential, None if the field is not set or
holds a different branch.
Sourcepub fn set_user_credential<T: Into<Box<UserCredential>>>(self, v: T) -> Self
pub fn set_user_credential<T: Into<Box<UserCredential>>>(self, v: T) -> Self
Sets the value of identity
to hold a UserCredential.
Note that all the setters affecting identity are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::execution_identity::UserCredential;
let x = ExecutionIdentity::new().set_user_credential(UserCredential::default()/* use setters */);
assert!(x.user_credential().is_some());
assert!(x.dataplex_service_agent().is_none());
assert!(x.service_account().is_none());Sourcepub fn service_account(&self) -> Option<&Box<ServiceAccount>>
pub fn service_account(&self) -> Option<&Box<ServiceAccount>>
The value of identity
if it holds a ServiceAccount, None if the field is not set or
holds a different branch.
Sourcepub fn set_service_account<T: Into<Box<ServiceAccount>>>(self, v: T) -> Self
pub fn set_service_account<T: Into<Box<ServiceAccount>>>(self, v: T) -> Self
Sets the value of identity
to hold a ServiceAccount.
Note that all the setters affecting identity are
mutually exclusive.
Example
use google_cloud_dataplex_v1::model::execution_identity::ServiceAccount;
let x = ExecutionIdentity::new().set_service_account(ServiceAccount::default()/* use setters */);
assert!(x.service_account().is_some());
assert!(x.dataplex_service_agent().is_none());
assert!(x.user_credential().is_none());Trait Implementations
Sourceimpl Clone for ExecutionIdentity
impl Clone for ExecutionIdentity
Sourcefn clone(&self) -> ExecutionIdentity
fn clone(&self) -> ExecutionIdentity
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExecutionIdentity
impl Debug for ExecutionIdentity
Sourceimpl Default for ExecutionIdentity
impl Default for ExecutionIdentity
Sourcefn default() -> ExecutionIdentity
fn default() -> ExecutionIdentity
Sourceimpl Message for ExecutionIdentity
impl Message for ExecutionIdentity
Sourceimpl PartialEq for ExecutionIdentity
impl PartialEq for ExecutionIdentity
Sourcefn eq(&self, other: &ExecutionIdentity) -> bool
fn eq(&self, other: &ExecutionIdentity) -> bool
self and other values to be equal, and is used by ==.