#[non_exhaustive]pub struct ListMetadataFeedsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request message for ListMetadataFeedsRequest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the parent location, in the format
projects/{project_id_or_number}/locations/{location_id}
page_size: i32Optional. The maximum number of metadata feeds to return. The service might return fewer feeds than this value. If unspecified, at most 10 feeds are returned. The maximum value is 1,000.
page_token: StringOptional. The page token received from a previous ListMetadataFeeds call.
Provide this token to retrieve the subsequent page of results. When
paginating, all other parameters that are provided to the
ListMetadataFeeds request must match the call that provided the
page token.
filter: StringOptional. Filter request. Filters are case-sensitive. The service supports the following formats:
labels.key1 = "value1"labels:key1name = "value"
You can combine filters with AND, OR, and NOT operators.
order_by: StringOptional. The field to sort the results by, either name or create_time.
If not specified, the ordering is undefined.
Implementations
Sourceimpl ListMetadataFeedsRequest
impl ListMetadataFeedsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListMetadataFeedsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self