#[non_exhaustive]pub struct ModifyEntryRequest {
pub name: String,
pub entry: Option<Entry>,
pub update_mask: Option<FieldMask>,
pub delete_missing_aspects: bool,
pub aspect_keys: Vec<String>,
/* private fields */
}Expand description
Modify Entry request using permissions in the source system.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The project to which the request should be attributed in the
following form: projects/{project}/locations/{location}.
entry: Option<Entry>Required. The entry to modify.
update_mask: Option<FieldMask>Optional. Mask of fields to update. To update Aspects, the update_mask must contain the value “aspects”.
If the update_mask is empty, the service will update all modifiable fields present in the request.
delete_missing_aspects: boolOptional. If set to true, any aspects not specified in the request will be deleted. The default is false.
aspect_keys: Vec<String>Optional. The aspect keys which the service should modify. It supports the following syntaxes:
<aspect_type_reference>- matches an aspect of the given type and empty path.<aspect_type_reference>@path- matches an aspect of the given type and specified path. For example, to attach an aspect to a field that is specified by theschemaaspect, the path should have the formatSchema.<field_name>.<aspect_type_reference>@*- matches aspects of the given type for all paths.*@path- matches aspects of all types on the given path.
The service will not remove existing aspects matching the syntax unless
delete_missing_aspects is set to true.
If this field is left empty, the service treats it as specifying exactly those Aspects present in the request.
Implementations
Sourceimpl ModifyEntryRequest
impl ModifyEntryRequest
Sourcepub fn set_or_clear_entry<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_entry<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = ModifyEntryRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = ModifyEntryRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = ModifyEntryRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_delete_missing_aspects<T: Into<bool>>(self, v: T) -> Self
pub fn set_delete_missing_aspects<T: Into<bool>>(self, v: T) -> Self
Sets the value of delete_missing_aspects.
Example
let x = ModifyEntryRequest::new().set_delete_missing_aspects(true);Sourcepub fn set_aspect_keys<T, V>(self, v: T) -> Self
pub fn set_aspect_keys<T, V>(self, v: T) -> Self
Sets the value of aspect_keys.
Example
let x = ModifyEntryRequest::new().set_aspect_keys(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ModifyEntryRequest
impl Clone for ModifyEntryRequest
Sourcefn clone(&self) -> ModifyEntryRequest
fn clone(&self) -> ModifyEntryRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ModifyEntryRequest
impl Debug for ModifyEntryRequest
Sourceimpl Default for ModifyEntryRequest
impl Default for ModifyEntryRequest
Sourcefn default() -> ModifyEntryRequest
fn default() -> ModifyEntryRequest
Sourceimpl Message for ModifyEntryRequest
impl Message for ModifyEntryRequest
Sourceimpl PartialEq for ModifyEntryRequest
impl PartialEq for ModifyEntryRequest
impl StructuralPartialEq for ModifyEntryRequest